@@ -4,7 +4,7 @@ source hack/common.sh
 source hack/bootstrap.sh
 source hack/config.sh
 
-WHAT=${WHAT:=-"//staging/src/kubevirt.io/client-go/... //pkg/... //cmd/... //tests/framework/..."}
+WHAT=${WHAT:-"//staging/src/kubevirt.io/client-go/... //pkg/... //cmd/... //tests/framework/..."}
 
 rm -rf ${ARTIFACTS}/junit ${ARTIFACTS}/testlogs
 
