@@ -7,7 +7,6 @@ source $(dirname "$0")/config.sh
 
 # generate clients
 CLIENT_GEN_BASE=kubevirt.io/client-go/generated
-rm -rf ${KUBEVIRT_DIR}/staging/src/${CLIENT_GEN_BASE}
 
 # KubeVirt stuff
 swagger-doc -in ${KUBEVIRT_DIR}/staging/src/kubevirt.io/api/core/v1/types.go
@@ -50,7 +49,7 @@ fi
 
 client-gen --clientset-name versioned \
     --input-base kubevirt.io/api \
-    --input export/v1alpha1,snapshot/v1alpha1,instancetype/v1alpha1,instancetype/v1alpha2,instancetype/v1beta1,pool/v1alpha1,migrations/v1alpha1,clone/v1alpha1 \
+    --input core/v1,export/v1alpha1,snapshot/v1alpha1,instancetype/v1alpha1,instancetype/v1alpha2,instancetype/v1beta1,pool/v1alpha1,migrations/v1alpha1,clone/v1alpha1 \
     --output-base ${KUBEVIRT_DIR}/staging/src \
     --output-package ${CLIENT_GEN_BASE}/kubevirt/clientset \
     --go-header-file ${KUBEVIRT_DIR}/hack/boilerplate/boilerplate.go.txt
@@ -64,7 +63,7 @@ client-gen --clientset-name versioned \
     --go-header-file ${KUBEVIRT_DIR}/hack/boilerplate/boilerplate.go.txt
 
 client-gen --clientset-name versioned \
-    --input-base github.com/coreos/prometheus-operator/pkg/apis \
+    --input-base github.com/prometheus-operator/prometheus-operator/pkg/apis \
     --input monitoring/v1 \
     --output-base ${KUBEVIRT_DIR}/staging/src \
     --output-package ${CLIENT_GEN_BASE}/prometheus-operator/clientset \
@@ -183,6 +182,7 @@ virtexportproxy_sha=$(getShasum ".VirtExportProxySha")
 virtexportserver_sha=$(getShasum ".VirtExportServerSha")
 gs_sha=$(getShasum ".GsSha")
 pr_helper_sha=$(getShasum ".PrHelperSha")
+sidecar_shim_sha=$(getShasum ".SidecarShimSha")
 
 virtapi_rawsha=$(getRawShasum ".VirtApiSha")
 virtcontroller_rawsha=$(getRawShasum ".VirtControllerSha")
@@ -192,6 +192,7 @@ virtexportproxy_rawsha=$(getRawShasum ".VirtExportProxySha")
 virtexportserver_rawsha=$(getRawShasum ".VirtExportServerSha")
 gs_rawsha=$(getRawShasum ".GsSha")
 prhelper_rawsha=$(getRawShasum ".PrHelperSha")
+sidecar_shim_rawsha=$(getRawShasum ".SidecarShimSha")
 
 # The generation code for CSV requires a valid semver to be used.
 # But we're trying to generate a template for a CSV here from code
@@ -200,7 +201,28 @@ prhelper_rawsha=$(getRawShasum ".PrHelperSha")
 # values after the file is generated.
 _fake_replaces_csv_version="1111.1111.1111"
 _fake_csv_version="2222.2222.2222"
-${KUBEVIRT_DIR}/tools/csv-generator/csv-generator --namespace={{.CSVNamespace}} --dockerPrefix={{.DockerPrefix}} --operatorImageVersion="$virtoperator_version" --pullPolicy={{.ImagePullPolicy}} --verbosity={{.Verbosity}} --apiSha="$virtapi_rawsha" --controllerSha="$virtcontroller_rawsha" --handlerSha="$virthandler_rawsha" --launcherSha="$virtlauncher_rawsha" --exportProxySha="$virtexportproxy_rawsha" --exportServerSha="$virtexportserver_rawsha" --gsSha="$gs_rawsha" --prHelperSha="$prhelper_rawsha" --kubevirtLogo={{.KubeVirtLogo}} --csvVersion="$_fake_csv_version" --replacesCsvVersion="$_fake_replaces_csv_version" --csvCreatedAtTimestamp={{.CreatedAt}} --kubeVirtVersion={{.DockerTag}} >${KUBEVIRT_DIR}/manifests/generated/operator-csv.yaml.in
+${KUBEVIRT_DIR}/tools/csv-generator/csv-generator \
+    --apiSha="$virtapi_rawsha" \
+    --controllerSha="$virtcontroller_rawsha" \
+    --csvCreatedAtTimestamp={{.CreatedAt}} \
+    --csvVersion="$_fake_csv_version" \
+    --dockerPrefix={{.DockerPrefix}} \
+    --exportProxySha="$virtexportproxy_rawsha" \
+    --exportServerSha="$virtexportserver_rawsha" \
+    --gsSha="$gs_rawsha" \
+    --handlerSha="$virthandler_rawsha" \
+    --kubevirtLogo={{.KubeVirtLogo}} \
+    --kubeVirtVersion={{.DockerTag}} \
+    --launcherSha="$virtlauncher_rawsha" \
+    --namespace={{.CSVNamespace}} \
+    --operatorImageVersion="$virtoperator_version" \
+    --prHelperSha="$prhelper_rawsha" \
+    --pullPolicy={{.ImagePullPolicy}} \
+    --replacesCsvVersion="$_fake_replaces_csv_version" \
+    --sidecarShimSha="$sidecar_shim_rawsha" \
+    --verbosity={{.Verbosity}} \
+    >${KUBEVIRT_DIR}/manifests/generated/operator-csv.yaml.in
+
 sed -i "s/$_fake_csv_version/{{.CsvVersion}}/g" ${KUBEVIRT_DIR}/manifests/generated/operator-csv.yaml.in
 sed -i "s/$_fake_replaces_csv_version/{{.ReplacesCsvVersion}}/g" ${KUBEVIRT_DIR}/manifests/generated/operator-csv.yaml.in
 
