@@ -5,9 +5,10 @@ import (
 	"context"
 	"fmt"
 
-	"github.com/golang/mock/gomock"
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
+
+	"github.com/golang/mock/gomock"
 	appsv1 "k8s.io/api/apps/v1"
 	k8sv1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
@@ -18,7 +19,7 @@ import (
 	"k8s.io/apimachinery/pkg/util/json"
 	"k8s.io/client-go/testing"
 	"k8s.io/client-go/tools/cache"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
 
 	k8sfield "k8s.io/apimachinery/pkg/util/validation/field"
 	k8sfake "k8s.io/client-go/kubernetes/fake"
@@ -227,7 +228,7 @@ var _ = Describe("Instancetype and Preferences", func() {
 				expectedRevisionNamePatch, err := instancetype.GenerateRevisionNamePatch(clusterInstancetypeControllerRevision, nil)
 				Expect(err).ToNot(HaveOccurred())
 
-				vmInterface.EXPECT().Patch(context.Background(), vm.Name, types.JSONPatchType, expectedRevisionNamePatch, &metav1.PatchOptions{})
+				vmInterface.EXPECT().Patch(context.Background(), vm.Name, types.JSONPatchType, expectedRevisionNamePatch, metav1.PatchOptions{})
 
 				expectControllerRevisionCreation(clusterInstancetypeControllerRevision)
 
@@ -270,7 +271,7 @@ var _ = Describe("Instancetype and Preferences", func() {
 				expectedRevisionNamePatch, err := instancetype.GenerateRevisionNamePatch(instancetypeControllerRevision, nil)
 				Expect(err).ToNot(HaveOccurred())
 
-				vmInterface.EXPECT().Patch(context.Background(), vm.Name, types.JSONPatchType, expectedRevisionNamePatch, &metav1.PatchOptions{})
+				vmInterface.EXPECT().Patch(context.Background(), vm.Name, types.JSONPatchType, expectedRevisionNamePatch, metav1.PatchOptions{})
 
 				Expect(instancetypeMethods.StoreControllerRevisions(vm)).To(Succeed())
 				Expect(vm.Spec.Instancetype.RevisionName).To(Equal(instancetypeControllerRevision.Name))
@@ -300,9 +301,9 @@ var _ = Describe("Instancetype and Preferences", func() {
 				clusterInstancetype.Spec.CPU = instancetypev1beta1.CPUInstancetype{
 					Guest: uint32(2),
 					// Set the following values to be compatible with objects converted from v1alpha1
-					Model:                 pointer.String(""),
-					DedicatedCPUPlacement: pointer.Bool(false),
-					IsolateEmulatorThread: pointer.Bool(false),
+					Model:                 ptr.To(""),
+					DedicatedCPUPlacement: ptr.To(false),
+					IsolateEmulatorThread: ptr.To(false),
 				}
 
 				specData, err := json.Marshal(clusterInstancetype.Spec)
@@ -417,7 +418,7 @@ var _ = Describe("Instancetype and Preferences", func() {
 				expectedRevisionNamePatch, err := instancetype.GenerateRevisionNamePatch(instancetypeControllerRevision, nil)
 				Expect(err).ToNot(HaveOccurred())
 
-				vmInterface.EXPECT().Patch(context.Background(), vm.Name, types.JSONPatchType, expectedRevisionNamePatch, &metav1.PatchOptions{})
+				vmInterface.EXPECT().Patch(context.Background(), vm.Name, types.JSONPatchType, expectedRevisionNamePatch, metav1.PatchOptions{})
 
 				expectControllerRevisionCreation(instancetypeControllerRevision)
 
@@ -459,7 +460,7 @@ var _ = Describe("Instancetype and Preferences", func() {
 				expectedRevisionNamePatch, err := instancetype.GenerateRevisionNamePatch(instancetypeControllerRevision, nil)
 				Expect(err).ToNot(HaveOccurred())
 
-				vmInterface.EXPECT().Patch(context.Background(), vm.Name, types.JSONPatchType, expectedRevisionNamePatch, &metav1.PatchOptions{})
+				vmInterface.EXPECT().Patch(context.Background(), vm.Name, types.JSONPatchType, expectedRevisionNamePatch, metav1.PatchOptions{})
 
 				Expect(instancetypeMethods.StoreControllerRevisions(vm)).To(Succeed())
 				Expect(vm.Spec.Instancetype.RevisionName).To(Equal(instancetypeControllerRevision.Name))
@@ -490,9 +491,9 @@ var _ = Describe("Instancetype and Preferences", func() {
 				fakeInstancetype.Spec.CPU = instancetypev1beta1.CPUInstancetype{
 					Guest: uint32(2),
 					// Set the following values to be compatible with objects converted from v1alpha1
-					Model:                 pointer.String(""),
-					DedicatedCPUPlacement: pointer.Bool(false),
-					IsolateEmulatorThread: pointer.Bool(false),
+					Model:                 ptr.To(""),
+					DedicatedCPUPlacement: ptr.To(false),
+					IsolateEmulatorThread: ptr.To(false),
 				}
 
 				specData, err := json.Marshal(fakeInstancetype.Spec)
@@ -676,7 +677,7 @@ var _ = Describe("Instancetype and Preferences", func() {
 				expectedRevisionNamePatch, err := instancetype.GenerateRevisionNamePatch(nil, clusterPreferenceControllerRevision)
 				Expect(err).ToNot(HaveOccurred())
 
-				vmInterface.EXPECT().Patch(context.Background(), vm.Name, types.JSONPatchType, expectedRevisionNamePatch, &metav1.PatchOptions{})
+				vmInterface.EXPECT().Patch(context.Background(), vm.Name, types.JSONPatchType, expectedRevisionNamePatch, metav1.PatchOptions{})
 
 				expectControllerRevisionCreation(clusterPreferenceControllerRevision)
 
@@ -714,7 +715,7 @@ var _ = Describe("Instancetype and Preferences", func() {
 				expectedRevisionNamePatch, err := instancetype.GenerateRevisionNamePatch(nil, clusterPreferenceControllerRevision)
 				Expect(err).ToNot(HaveOccurred())
 
-				vmInterface.EXPECT().Patch(context.Background(), vm.Name, types.JSONPatchType, expectedRevisionNamePatch, &metav1.PatchOptions{})
+				vmInterface.EXPECT().Patch(context.Background(), vm.Name, types.JSONPatchType, expectedRevisionNamePatch, metav1.PatchOptions{})
 
 				Expect(instancetypeMethods.StoreControllerRevisions(vm)).To(Succeed())
 				Expect(vm.Spec.Preference.RevisionName).To(Equal(clusterPreferenceControllerRevision.Name))
@@ -811,7 +812,7 @@ var _ = Describe("Instancetype and Preferences", func() {
 				expectedRevisionNamePatch, err := instancetype.GenerateRevisionNamePatch(nil, preferenceControllerRevision)
 				Expect(err).ToNot(HaveOccurred())
 
-				vmInterface.EXPECT().Patch(context.Background(), vm.Name, types.JSONPatchType, expectedRevisionNamePatch, &metav1.PatchOptions{})
+				vmInterface.EXPECT().Patch(context.Background(), vm.Name, types.JSONPatchType, expectedRevisionNamePatch, metav1.PatchOptions{})
 
 				expectControllerRevisionCreation(preferenceControllerRevision)
 
@@ -851,7 +852,7 @@ var _ = Describe("Instancetype and Preferences", func() {
 				expectedRevisionNamePatch, err := instancetype.GenerateRevisionNamePatch(nil, preferenceControllerRevision)
 				Expect(err).ToNot(HaveOccurred())
 
-				vmInterface.EXPECT().Patch(context.Background(), vm.Name, types.JSONPatchType, expectedRevisionNamePatch, &metav1.PatchOptions{})
+				vmInterface.EXPECT().Patch(context.Background(), vm.Name, types.JSONPatchType, expectedRevisionNamePatch, metav1.PatchOptions{})
 
 				Expect(instancetypeMethods.StoreControllerRevisions(vm)).To(Succeed())
 				Expect(vm.Spec.Preference.RevisionName).To(Equal(preferenceControllerRevision.Name))
@@ -1000,9 +1001,9 @@ var _ = Describe("Instancetype and Preferences", func() {
 				instancetypeSpec = &instancetypev1beta1.VirtualMachineInstancetypeSpec{
 					CPU: instancetypev1beta1.CPUInstancetype{
 						Guest:                 uint32(2),
-						Model:                 pointer.String("host-passthrough"),
-						DedicatedCPUPlacement: pointer.Bool(true),
-						IsolateEmulatorThread: pointer.Bool(true),
+						Model:                 ptr.To("host-passthrough"),
+						DedicatedCPUPlacement: ptr.To(true),
+						IsolateEmulatorThread: ptr.To(true),
 						NUMA: &v1.NUMA{
 							GuestMappingPassthrough: &v1.NUMAGuestMappingPassthrough{},
 						},
@@ -1502,13 +1503,13 @@ var _ = Describe("Instancetype and Preferences", func() {
 						Physical: 512,
 					},
 				}
-				vmi.Spec.Domain.Devices.AutoattachGraphicsDevice = pointer.Bool(false)
-				vmi.Spec.Domain.Devices.AutoattachMemBalloon = pointer.Bool(false)
+				vmi.Spec.Domain.Devices.AutoattachGraphicsDevice = ptr.To(false)
+				vmi.Spec.Domain.Devices.AutoattachMemBalloon = ptr.To(false)
 				vmi.Spec.Domain.Devices.Disks = []v1.Disk{
 					{
 						Cache:             v1.CacheWriteBack,
 						IO:                v1.IONative,
-						DedicatedIOThread: pointer.Bool(false),
+						DedicatedIOThread: ptr.To(false),
 						BlockSize:         userDefinedBlockSize,
 						DiskDevice: v1.DiskDevice{
 							Disk: &v1.DiskTarget{
@@ -1566,16 +1567,16 @@ var _ = Describe("Instancetype and Preferences", func() {
 
 				preferenceSpec = &instancetypev1beta1.VirtualMachinePreferenceSpec{
 					Devices: &instancetypev1beta1.DevicePreferences{
-						PreferredAutoattachGraphicsDevice:   pointer.Bool(true),
-						PreferredAutoattachMemBalloon:       pointer.Bool(true),
-						PreferredAutoattachPodInterface:     pointer.Bool(true),
-						PreferredAutoattachSerialConsole:    pointer.Bool(true),
-						PreferredAutoattachInputDevice:      pointer.Bool(true),
-						PreferredDiskDedicatedIoThread:      pointer.Bool(true),
-						PreferredDisableHotplug:             pointer.Bool(true),
-						PreferredUseVirtioTransitional:      pointer.Bool(true),
-						PreferredNetworkInterfaceMultiQueue: pointer.Bool(true),
-						PreferredBlockMultiQueue:            pointer.Bool(true),
+						PreferredAutoattachGraphicsDevice:   ptr.To(true),
+						PreferredAutoattachMemBalloon:       ptr.To(true),
+						PreferredAutoattachPodInterface:     ptr.To(true),
+						PreferredAutoattachSerialConsole:    ptr.To(true),
+						PreferredAutoattachInputDevice:      ptr.To(true),
+						PreferredDiskDedicatedIoThread:      ptr.To(true),
+						PreferredDisableHotplug:             ptr.To(true),
+						PreferredUseVirtioTransitional:      ptr.To(true),
+						PreferredNetworkInterfaceMultiQueue: ptr.To(true),
+						PreferredBlockMultiQueue:            ptr.To(true),
 						PreferredDiskBlockSize: &v1.BlockSize{
 							Custom: &v1.CustomBlockSize{
 								Logical:  4096,
@@ -1693,26 +1694,26 @@ var _ = Describe("Instancetype and Preferences", func() {
 					Features: &instancetypev1beta1.FeaturePreferences{
 						PreferredAcpi: &v1.FeatureState{},
 						PreferredApic: &v1.FeatureAPIC{
-							Enabled:        pointer.Bool(true),
+							Enabled:        ptr.To(true),
 							EndOfInterrupt: false,
 						},
 						PreferredHyperv: &v1.FeatureHyperv{
 							Relaxed: &v1.FeatureState{},
 							VAPIC:   &v1.FeatureState{},
 							Spinlocks: &v1.FeatureSpinlocks{
-								Enabled: pointer.Bool(true),
+								Enabled: ptr.To(true),
 								Retries: &spinLockRetries,
 							},
 							VPIndex: &v1.FeatureState{},
 							Runtime: &v1.FeatureState{},
 							SyNIC:   &v1.FeatureState{},
 							SyNICTimer: &v1.SyNICTimer{
-								Enabled: pointer.Bool(true),
+								Enabled: ptr.To(true),
 								Direct:  &v1.FeatureState{},
 							},
 							Reset: &v1.FeatureState{},
 							VendorID: &v1.FeatureVendorID{
-								Enabled:  pointer.Bool(true),
+								Enabled:  ptr.To(true),
 								VendorID: "1234",
 							},
 							Frequencies:     &v1.FeatureState{},
@@ -1746,7 +1747,7 @@ var _ = Describe("Instancetype and Preferences", func() {
 				vmi.Spec.Domain.Features = &v1.Features{
 					Hyperv: &v1.FeatureHyperv{
 						EVMCS: &v1.FeatureState{
-							Enabled: pointer.Bool(false),
+							Enabled: ptr.To(false),
 						},
 					},
 				}
@@ -1763,10 +1764,10 @@ var _ = Describe("Instancetype and Preferences", func() {
 			It("should apply BIOS preferences full to VMI", func() {
 				preferenceSpec = &instancetypev1beta1.VirtualMachinePreferenceSpec{
 					Firmware: &instancetypev1beta1.FirmwarePreferences{
-						PreferredUseBios:       pointer.Bool(true),
-						PreferredUseBiosSerial: pointer.Bool(true),
-						PreferredUseEfi:        pointer.Bool(false),
-						PreferredUseSecureBoot: pointer.Bool(false),
+						PreferredUseBios:       ptr.To(true),
+						PreferredUseBiosSerial: ptr.To(true),
+						PreferredUseEfi:        ptr.To(false),
+						PreferredUseSecureBoot: ptr.To(false),
 					},
 				}
 
@@ -1779,10 +1780,10 @@ var _ = Describe("Instancetype and Preferences", func() {
 			It("should apply SecureBoot preferences full to VMI", func() {
 				preferenceSpec = &instancetypev1beta1.VirtualMachinePreferenceSpec{
 					Firmware: &instancetypev1beta1.FirmwarePreferences{
-						PreferredUseBios:       pointer.Bool(false),
-						PreferredUseBiosSerial: pointer.Bool(false),
-						PreferredUseEfi:        pointer.Bool(true),
-						PreferredUseSecureBoot: pointer.Bool(true),
+						PreferredUseBios:       ptr.To(false),
+						PreferredUseBiosSerial: ptr.To(false),
+						PreferredUseEfi:        ptr.To(true),
+						PreferredUseSecureBoot: ptr.To(true),
 					},
 				}
 
@@ -1795,14 +1796,14 @@ var _ = Describe("Instancetype and Preferences", func() {
 			It("should not overwrite user defined Bootloader.BIOS with PreferredUseEfi - bug #10313", func() {
 				preferenceSpec = &instancetypev1beta1.VirtualMachinePreferenceSpec{
 					Firmware: &instancetypev1beta1.FirmwarePreferences{
-						PreferredUseEfi:        pointer.Bool(true),
-						PreferredUseSecureBoot: pointer.Bool(true),
+						PreferredUseEfi:        ptr.To(true),
+						PreferredUseSecureBoot: ptr.To(true),
 					},
 				}
 				vmi.Spec.Domain.Firmware = &v1.Firmware{
 					Bootloader: &v1.Bootloader{
 						BIOS: &v1.BIOS{
-							UseSerial: pointer.Bool(false),
+							UseSerial: ptr.To(false),
 						},
 					},
 				}
@@ -1814,14 +1815,14 @@ var _ = Describe("Instancetype and Preferences", func() {
 			It("should not overwrite user defined value with PreferredUseBiosSerial - bug #10313", func() {
 				preferenceSpec = &instancetypev1beta1.VirtualMachinePreferenceSpec{
 					Firmware: &instancetypev1beta1.FirmwarePreferences{
-						PreferredUseBios:       pointer.Bool(true),
-						PreferredUseBiosSerial: pointer.Bool(true),
+						PreferredUseBios:       ptr.To(true),
+						PreferredUseBiosSerial: ptr.To(true),
 					},
 				}
 				vmi.Spec.Domain.Firmware = &v1.Firmware{
 					Bootloader: &v1.Bootloader{
 						BIOS: &v1.BIOS{
-							UseSerial: pointer.Bool(false),
+							UseSerial: ptr.To(false),
 						},
 					},
 				}
@@ -1832,14 +1833,14 @@ var _ = Describe("Instancetype and Preferences", func() {
 			It("should not overwrite user defined Bootloader.EFI with PreferredUseBios - bug #10313", func() {
 				preferenceSpec = &instancetypev1beta1.VirtualMachinePreferenceSpec{
 					Firmware: &instancetypev1beta1.FirmwarePreferences{
-						PreferredUseBios:       pointer.Bool(true),
-						PreferredUseBiosSerial: pointer.Bool(true),
+						PreferredUseBios:       ptr.To(true),
+						PreferredUseBiosSerial: ptr.To(true),
 					},
 				}
 				vmi.Spec.Domain.Firmware = &v1.Firmware{
 					Bootloader: &v1.Bootloader{
 						EFI: &v1.EFI{
-							SecureBoot: pointer.Bool(false),
+							SecureBoot: ptr.To(false),
 						},
 					},
 				}
@@ -1851,14 +1852,14 @@ var _ = Describe("Instancetype and Preferences", func() {
 			It("should not overwrite user defined value with PreferredUseSecureBoot - bug #10313", func() {
 				preferenceSpec = &instancetypev1beta1.VirtualMachinePreferenceSpec{
 					Firmware: &instancetypev1beta1.FirmwarePreferences{
-						PreferredUseEfi:        pointer.Bool(true),
-						PreferredUseSecureBoot: pointer.Bool(true),
+						PreferredUseEfi:        ptr.To(true),
+						PreferredUseSecureBoot: ptr.To(true),
 					},
 				}
 				vmi.Spec.Domain.Firmware = &v1.Firmware{
 					Bootloader: &v1.Bootloader{
 						EFI: &v1.EFI{
-							SecureBoot: pointer.Bool(false),
+							SecureBoot: ptr.To(false),
 						},
 					},
 				}
@@ -1889,7 +1890,7 @@ var _ = Describe("Instancetype and Preferences", func() {
 					Clock: &instancetypev1beta1.ClockPreferences{
 						PreferredClockOffset: &v1.ClockOffset{
 							UTC: &v1.ClockOffsetUTC{
-								OffsetSeconds: pointer.Int(30),
+								OffsetSeconds: ptr.To(30),
 							},
 						},
 						PreferredTimer: &v1.Timer{
@@ -1909,7 +1910,7 @@ var _ = Describe("Instancetype and Preferences", func() {
 		Context("Preference.PreferredSubdomain", func() {
 			It("should apply to VMI", func() {
 				preferenceSpec = &instancetypev1beta1.VirtualMachinePreferenceSpec{
-					PreferredSubdomain: pointer.String("kubevirt.io"),
+					PreferredSubdomain: ptr.To("kubevirt.io"),
 				}
 				Expect(instancetypeMethods.ApplyToVmi(field, instancetypeSpec, preferenceSpec, &vmi.Spec, &vmi.ObjectMeta)).To(BeEmpty())
 				Expect(vmi.Spec.Subdomain).To(Equal(*preferenceSpec.PreferredSubdomain))
@@ -1919,7 +1920,7 @@ var _ = Describe("Instancetype and Preferences", func() {
 				const userDefinedValue = "foo.com"
 				vmi.Spec.Subdomain = userDefinedValue
 				preferenceSpec = &instancetypev1beta1.VirtualMachinePreferenceSpec{
-					PreferredSubdomain: pointer.String("kubevirt.io"),
+					PreferredSubdomain: ptr.To("kubevirt.io"),
 				}
 				Expect(instancetypeMethods.ApplyToVmi(field, instancetypeSpec, preferenceSpec, &vmi.Spec, &vmi.ObjectMeta)).To(BeEmpty())
 				Expect(vmi.Spec.Subdomain).To(Equal(userDefinedValue))
@@ -1929,7 +1930,7 @@ var _ = Describe("Instancetype and Preferences", func() {
 		Context("Preference.PreferredTerminationGracePeriodSeconds", func() {
 			It("should apply to VMI", func() {
 				preferenceSpec = &instancetypev1beta1.VirtualMachinePreferenceSpec{
-					PreferredTerminationGracePeriodSeconds: pointer.Int64(180),
+					PreferredTerminationGracePeriodSeconds: ptr.To(int64(180)),
 				}
 				Expect(instancetypeMethods.ApplyToVmi(field, instancetypeSpec, preferenceSpec, &vmi.Spec, &vmi.ObjectMeta)).To(BeEmpty())
 				Expect(*vmi.Spec.TerminationGracePeriodSeconds).To(Equal(*preferenceSpec.PreferredTerminationGracePeriodSeconds))
@@ -1937,9 +1938,9 @@ var _ = Describe("Instancetype and Preferences", func() {
 
 			It("should not overwrite user defined value", func() {
 				const userDefinedValue = int64(100)
-				vmi.Spec.TerminationGracePeriodSeconds = pointer.Int64(userDefinedValue)
+				vmi.Spec.TerminationGracePeriodSeconds = ptr.To(userDefinedValue)
 				preferenceSpec = &instancetypev1beta1.VirtualMachinePreferenceSpec{
-					PreferredTerminationGracePeriodSeconds: pointer.Int64(180),
+					PreferredTerminationGracePeriodSeconds: ptr.To(int64(180)),
 				}
 				Expect(instancetypeMethods.ApplyToVmi(field, instancetypeSpec, preferenceSpec, &vmi.Spec, &vmi.ObjectMeta)).To(BeEmpty())
 				Expect(*vmi.Spec.TerminationGracePeriodSeconds).To(Equal(userDefinedValue))
