@@ -47,7 +47,6 @@ const (
 	MigrateVmiDataProcessedMetricName      = "kubevirt_vmi_migration_data_processed_bytes"
 	MigrateVmiDirtyMemoryRateMetricName    = "kubevirt_vmi_migration_dirty_memory_rate_bytes"
 	MigrateVmiMemoryTransferRateMetricName = "kubevirt_vmi_migration_disk_transfer_rate_bytes"
-	MigrateVmiDiskTransferRateMetricName   = "kubevirt_vmi_migration_memory_transfer_rate_bytes"
 )
 
 var (
@@ -111,15 +110,6 @@ func (metrics *vmiMetrics) updateMigrateInfo(jobInfo *stats.DomainJobInfo) {
 			float64(jobInfo.MemoryBps),
 		)
 	}
-
-	if jobInfo.DiskBpsSet {
-		metrics.pushCommonMetric(
-			MigrateVmiDiskTransferRateMetricName,
-			"Network throughput used while migrating disks in Bytes per second.",
-			prometheus.GaugeValue,
-			float64(jobInfo.DiskBps),
-		)
-	}
 }
 
 func (metrics *vmiMetrics) updateMemory(mem *stats.DomainStatsMemory) {
@@ -288,7 +278,7 @@ func (metrics *vmiMetrics) updateVcpu(vcpuStats []stats.DomainStatsVcpu) {
 				"kubevirt_vmi_vcpu_seconds_total",
 				"Total amount of time spent in each state by each vcpu (cpu_time excluding hypervisor time). Where `id` is the vcpu identifier and `state` can be one of the following: [`OFFLINE`, `RUNNING`, `BLOCKED`].",
 				prometheus.CounterValue,
-				float64(vcpu.Time/1000000000),
+				float64(vcpu.Time/1000000),
 				[]string{"id", "state"},
 				[]string{stringVcpuIdx, humanReadableState(vcpu.State)},
 			)
@@ -299,7 +289,7 @@ func (metrics *vmiMetrics) updateVcpu(vcpuStats []stats.DomainStatsVcpu) {
 				"kubevirt_vmi_vcpu_wait_seconds_total",
 				"Amount of time spent by each vcpu while waiting on I/O.",
 				prometheus.CounterValue,
-				float64(vcpu.Wait)/float64(1000000000),
+				float64(vcpu.Wait)/float64(1000000),
 				[]string{"id"},
 				[]string{stringVcpuIdx},
 			)
