@@ -330,6 +330,7 @@ func (n NetPod) bridgeBindingSpec(podIfaceName string, vmiIfaceIndex int, ifaceS
 	podIface := nmstate.Interface{
 		Index:       podStatusIface.Index,
 		Name:        podIfaceAlternativeName,
+		State:       nmstate.IfaceStateUp,
 		CopyMacFrom: bridgeIface.Name,
 		Controller:  bridgeIface.Name,
 		IPv4:        nmstate.IP{Enabled: pointer.P(false)},
@@ -505,7 +506,7 @@ func hasIP4GlobalUnicast(iface nmstate.Interface) bool {
 }
 
 func hasIP6GlobalUnicast(iface nmstate.Interface) bool {
-	return hasIPGlobalUnicast(iface.IPv4)
+	return hasIPGlobalUnicast(iface.IPv6)
 }
 
 func hasIPGlobalUnicast(ip nmstate.IP) bool {
@@ -548,7 +549,7 @@ func filterSupportedBindingNetworks(specNetworks []v1.Network, specInterfaces []
 			return nil, fmt.Errorf("no iface matching with network %s", network.Name)
 		}
 
-		if iface.Binding != nil || iface.SRIOV != nil || iface.Macvtap != nil {
+		if iface.SRIOV != nil || iface.Macvtap != nil {
 			continue
 		}
 
