@@ -92,8 +92,7 @@ func vmSnapshotSucceeded(vmSnapshot *snapshotv1.VirtualMachineSnapshot) bool {
 }
 
 func vmSnapshotProgressing(vmSnapshot *snapshotv1.VirtualMachineSnapshot) bool {
-	return vmSnapshotError(vmSnapshot) == nil && !VmSnapshotReady(vmSnapshot) &&
-		!vmSnapshotFailed(vmSnapshot) && !vmSnapshotSucceeded(vmSnapshot)
+	return !vmSnapshotFailed(vmSnapshot) && !vmSnapshotSucceeded(vmSnapshot)
 }
 
 func deleteContentPolicy(vmSnapshot *snapshotv1.VirtualMachineSnapshot) bool {
@@ -131,7 +130,7 @@ func vmSnapshotDeadlineExceeded(vmSnapshot *snapshotv1.VirtualMachineSnapshot) b
 	if vmSnapshotFailed(vmSnapshot) {
 		return true
 	}
-	if vmSnapshot.Status == nil || vmSnapshot.Status.Phase != snapshotv1.InProgress {
+	if !vmSnapshotProgressing(vmSnapshot) {
 		return false
 	}
 	return timeUntilDeadline(vmSnapshot) < 0
@@ -170,10 +169,12 @@ func (ctrl *VMSnapshotController) updateVMSnapshot(vmSnapshot *snapshotv1.Virtua
 		return 0, err
 	}
 
+	terminating := vmSnapshotTerminating(vmSnapshot)
+
 	// Make sure status is initialized before doing anything
 	if vmSnapshot.Status != nil {
 		if source != nil {
-			if vmSnapshotProgressing(vmSnapshot) && !vmSnapshotTerminating(vmSnapshot) {
+			if vmSnapshotProgressing(vmSnapshot) && !terminating {
 				// attempt to lock source
 				// if fails will attempt again when source is updated
 				if !source.Locked() {
@@ -201,7 +202,7 @@ func (ctrl *VMSnapshotController) updateVMSnapshot(vmSnapshot *snapshotv1.Virtua
 		}
 	}
 
-	if vmSnapshotTerminating(vmSnapshot) && content != nil {
+	if terminating && content != nil {
 		// Delete content if that's the policy or if the snapshot
 		// is marked to be deleted and the content is not ready yet
 		// - no point of keeping an unready content
@@ -217,7 +218,7 @@ func (ctrl *VMSnapshotController) updateVMSnapshot(vmSnapshot *snapshotv1.Virtua
 		}
 	}
 
-	if err = ctrl.updateSnapshotStatus(vmSnapshot, source); err != nil {
+	if err = ctrl.updateSnapshotStatus(vmSnapshot, content, source); err != nil {
 		return 0, err
 	}
 
@@ -292,7 +293,7 @@ func (ctrl *VMSnapshotController) updateVMSnapshotContent(content *snapshotv1.Vi
 
 	}
 
-	currentlyCreated := vmSnapshotContentCreated(content)
+	contentCreated := vmSnapshotContentCreated(content)
 	currentlyError := (content.Status != nil && content.Status.Error != nil) || vmSnapshotError(vmSnapshot) != nil
 
 	for _, volumeBackup := range content.Spec.VolumeBackups {
@@ -308,8 +309,8 @@ func (ctrl *VMSnapshotController) updateVMSnapshotContent(content *snapshotv1.Vi
 		}
 
 		if volumeSnapshot == nil {
-			// check if snapshot was deleted
-			if currentlyCreated {
+			// check if content was created and snapshot was deleted
+			if contentCreated {
 				log.Log.Warningf("VolumeSnapshot %s no longer exists", vsName)
 				ctrl.Recorder.Eventf(
 					content,
@@ -406,10 +407,13 @@ func (ctrl *VMSnapshotController) updateVMSnapshotContent(content *snapshotv1.Vi
 			if vss.CreationTime == nil {
 				created = false
 			}
-
 			if vss.ReadyToUse == nil || !*vss.ReadyToUse {
 				ready = false
 			}
+			if vss.Error != nil && vss.Error.Message != nil {
+				errorMessage = fmt.Sprintf("VolumeSnapshot %s error: %s", vss.VolumeSnapshotName, *vss.Error.Message)
+				break
+			}
 		}
 	}
 
@@ -422,7 +426,7 @@ func (ctrl *VMSnapshotController) updateVMSnapshotContent(content *snapshotv1.Vi
 		}
 	}
 
-	if errorMessage != "" {
+	if errorMessage != "" && !ready {
 		contentCpy.Status.Error = &snapshotv1.Error{
 			Time:    currentTime(),
 			Message: &errorMessage,
@@ -664,7 +668,7 @@ func (ctrl *VMSnapshotController) getVolumeSnapshotClass(storageClassName string
 	return "", fmt.Errorf("%d matching VolumeSnapshotClasses for %s", len(matches), storageClassName)
 }
 
-func (ctrl *VMSnapshotController) updateSnapshotStatus(vmSnapshot *snapshotv1.VirtualMachineSnapshot, source snapshotSource) error {
+func (ctrl *VMSnapshotController) updateSnapshotStatus(vmSnapshot *snapshotv1.VirtualMachineSnapshot, content *snapshotv1.VirtualMachineSnapshotContent, source snapshotSource) error {
 	f := false
 	vmSnapshotCpy := vmSnapshot.DeepCopy()
 	if vmSnapshotCpy.Status == nil {
@@ -673,40 +677,34 @@ func (ctrl *VMSnapshotController) updateSnapshotStatus(vmSnapshot *snapshotv1.Vi
 		}
 	}
 
+	canRemoveFinalizer := true
 	if source != nil {
 		uid := source.UID()
 		vmSnapshotCpy.Status.SourceUID = &uid
+		canRemoveFinalizer = !source.Locked()
 	}
 
-	content, err := ctrl.getContent(vmSnapshot)
-	if err != nil {
-		return err
-	}
-
-	if vmSnapshotDeleting(vmSnapshotCpy) {
-		// Enable the vmsnapshot to be deleted only in case it completed
-		// or after waiting until the content is deleted if needed
-		if !vmSnapshotProgressing(vmSnapshot) || contentDeletedIfNeeded(vmSnapshotCpy, content) {
-			controller.RemoveFinalizer(vmSnapshotCpy, vmSnapshotFinalizer)
-		}
-	} else {
-		// since no status subresource can update metadata and status
-		controller.AddFinalizer(vmSnapshotCpy, vmSnapshotFinalizer)
-
-		if content != nil && content.Status != nil {
-			// content exists and is initialized
-			vmSnapshotCpy.Status.VirtualMachineSnapshotContentName = &content.Name
-			vmSnapshotCpy.Status.CreationTime = content.Status.CreationTime
-			vmSnapshotCpy.Status.ReadyToUse = content.Status.ReadyToUse
-			vmSnapshotCpy.Status.Error = content.Status.Error
-		}
+	if content != nil && content.Status != nil {
+		// content exists and is initialized
+		vmSnapshotCpy.Status.VirtualMachineSnapshotContentName = &content.Name
+		vmSnapshotCpy.Status.CreationTime = content.Status.CreationTime
+		vmSnapshotCpy.Status.ReadyToUse = content.Status.ReadyToUse
+		vmSnapshotCpy.Status.Error = content.Status.Error
 	}
 
+	// terminal phase 1 - failed
 	if vmSnapshotDeadlineExceeded(vmSnapshotCpy) {
 		vmSnapshotCpy.Status.Phase = snapshotv1.Failed
 		updateSnapshotCondition(vmSnapshotCpy, newProgressingCondition(corev1.ConditionFalse, vmSnapshotDeadlineExceededError))
 		updateSnapshotCondition(vmSnapshotCpy, newFailureCondition(corev1.ConditionTrue, vmSnapshotDeadlineExceededError))
-	} else if vmSnapshotProgressing(vmSnapshotCpy) {
+		updateSnapshotCondition(vmSnapshotCpy, newReadyCondition(corev1.ConditionFalse, "Operation failed"))
+		// terminal phase 2 - succeeded
+	} else if vmSnapshotSucceeded(vmSnapshotCpy) || vmSnapshotCpy.Status.CreationTime != nil {
+		vmSnapshotCpy.Status.Phase = snapshotv1.Succeeded
+		updateSnapshotCondition(vmSnapshotCpy, newProgressingCondition(corev1.ConditionFalse, "Operation complete"))
+		updateSnapshotCondition(vmSnapshotCpy, newReadyCondition(corev1.ConditionTrue, "Operation complete"))
+		updateSnapshotSnapshotableVolumes(vmSnapshotCpy, content)
+	} else {
 		vmSnapshotCpy.Status.Phase = snapshotv1.InProgress
 		if source != nil {
 			if source.Locked() {
@@ -715,49 +713,41 @@ func (ctrl *VMSnapshotController) updateSnapshotStatus(vmSnapshot *snapshotv1.Vi
 				updateSnapshotCondition(vmSnapshotCpy, newProgressingCondition(corev1.ConditionFalse, "Source not locked"))
 			}
 
-			online, err := source.Online()
+			indications, err := updateVMSnapshotIndications(source)
 			if err != nil {
 				return err
 			}
-
-			indications := []snapshotv1.Indication{}
-			if online {
-				indications = append(indications, snapshotv1.VMSnapshotOnlineSnapshotIndication)
-
-				ga, err := source.GuestAgent()
-				if err != nil {
-					return err
-				}
-
-				if ga {
-					indications = append(indications, snapshotv1.VMSnapshotGuestAgentIndication)
-
-				} else {
-					indications = append(indications, snapshotv1.VMSnapshotNoGuestAgentIndication)
-				}
-			}
 			vmSnapshotCpy.Status.Indications = indications
 		} else {
 			updateSnapshotCondition(vmSnapshotCpy, newProgressingCondition(corev1.ConditionFalse, "Source does not exist"))
 		}
-		updateSnapshotCondition(vmSnapshotCpy, newReadyCondition(corev1.ConditionFalse, "Not ready"))
+
 		if vmSnapshotDeleting(vmSnapshotCpy) {
 			vmSnapshotCpy.Status.Phase = snapshotv1.Deleting
 			updateSnapshotCondition(vmSnapshotCpy, newProgressingCondition(corev1.ConditionFalse, "VM snapshot is deleting"))
-			updateSnapshotCondition(vmSnapshotCpy, newReadyCondition(corev1.ConditionFalse, "VM snapshot is deleting"))
 		}
-	} else if vmSnapshotError(vmSnapshotCpy) != nil {
-		updateSnapshotCondition(vmSnapshotCpy, newProgressingCondition(corev1.ConditionFalse, "In error state"))
-		updateSnapshotCondition(vmSnapshotCpy, newReadyCondition(corev1.ConditionFalse, "Error"))
-	} else if VmSnapshotReady(vmSnapshotCpy) {
-		vmSnapshotCpy.Status.Phase = snapshotv1.Succeeded
-		updateSnapshotCondition(vmSnapshotCpy, newProgressingCondition(corev1.ConditionFalse, "Operation complete"))
-		updateSnapshotCondition(vmSnapshotCpy, newReadyCondition(corev1.ConditionTrue, "Operation complete"))
-		updateSnapshotSnapshotableVolumes(vmSnapshotCpy, content)
+	}
+
+	if VmSnapshotReady(vmSnapshotCpy) {
+		updateSnapshotCondition(vmSnapshotCpy, newReadyCondition(corev1.ConditionTrue, "Ready"))
 	} else {
-		vmSnapshotCpy.Status.Phase = snapshotv1.Unknown
-		updateSnapshotCondition(vmSnapshotCpy, newProgressingCondition(corev1.ConditionUnknown, "Unknown state"))
-		updateSnapshotCondition(vmSnapshotCpy, newReadyCondition(corev1.ConditionUnknown, "Unknown state"))
+		updateSnapshotCondition(vmSnapshotCpy, newReadyCondition(corev1.ConditionFalse, "Not ready"))
+	}
+
+	if vmSnapshotError(vmSnapshotCpy) != nil {
+		updateSnapshotCondition(vmSnapshotCpy, newProgressingCondition(corev1.ConditionFalse, "In error state"))
+	}
+
+	if vmSnapshotDeleting(vmSnapshotCpy) {
+		// Enable the vmsnapshot to be deleted only in case the source is unlocked AND
+		// (the operation completed completed OR
+		// after waiting until the content is deleted if needed)
+		if canRemoveFinalizer && (!vmSnapshotProgressing(vmSnapshotCpy) || contentDeletedIfNeeded(vmSnapshotCpy, content)) {
+			controller.RemoveFinalizer(vmSnapshotCpy, vmSnapshotFinalizer)
+		}
+	} else {
+		// since no status subresource can update metadata and status
+		controller.AddFinalizer(vmSnapshotCpy, vmSnapshotFinalizer)
 	}
 
 	if !equality.Semantic.DeepEqual(vmSnapshot, vmSnapshotCpy) {
@@ -769,6 +759,31 @@ func (ctrl *VMSnapshotController) updateSnapshotStatus(vmSnapshot *snapshotv1.Vi
 	return nil
 }
 
+func updateVMSnapshotIndications(source snapshotSource) ([]snapshotv1.Indication, error) {
+	var indications []snapshotv1.Indication
+	online, err := source.Online()
+	if err != nil {
+		return indications, err
+	}
+
+	if online {
+		indications = append(indications, snapshotv1.VMSnapshotOnlineSnapshotIndication)
+
+		ga, err := source.GuestAgent()
+		if err != nil {
+			return indications, err
+		}
+
+		if ga {
+			indications = append(indications, snapshotv1.VMSnapshotGuestAgentIndication)
+
+		} else {
+			indications = append(indications, snapshotv1.VMSnapshotNoGuestAgentIndication)
+		}
+	}
+	return indications, nil
+}
+
 func updateSnapshotSnapshotableVolumes(snapshot *snapshotv1.VirtualMachineSnapshot, content *snapshotv1.VirtualMachineSnapshotContent) {
 	if content == nil {
 		return
