@@ -31,6 +31,7 @@ import (
 	"syscall"
 	"time"
 
+	"k8s.io/kube-openapi/pkg/common/restfuladapter"
 	"k8s.io/kube-openapi/pkg/validation/spec"
 
 	kvtls "kubevirt.io/kubevirt/pkg/util/tls"
@@ -59,6 +60,7 @@ import (
 	"kubevirt.io/kubevirt/pkg/certificates/bootstrap"
 	"kubevirt.io/kubevirt/pkg/controller"
 	"kubevirt.io/kubevirt/pkg/healthz"
+	metrics "kubevirt.io/kubevirt/pkg/monitoring/metrics/virt-api"
 	"kubevirt.io/kubevirt/pkg/monitoring/profiler"
 	mime "kubevirt.io/kubevirt/pkg/rest"
 	"kubevirt.io/kubevirt/pkg/rest/filter"
@@ -186,6 +188,12 @@ func (app *virtAPIApp) Execute() {
 	app.ConfigureOpenAPIService()
 	app.reInitChan = make(chan string, 10)
 
+	// setup monitoring
+	err = metrics.SetupMetrics()
+	if err != nil {
+		panic(err)
+	}
+
 	app.Run()
 }
 
@@ -776,7 +784,7 @@ func (app *virtAPIApp) Compose() {
 func (app *virtAPIApp) ConfigureOpenAPIService() {
 	config := openapi.CreateConfig()
 	config.GetDefinitions = v12.GetOpenAPIDefinitions
-	spec, err := builderv3.BuildOpenAPISpec(restful.RegisteredWebServices(), config)
+	spec, err := builderv3.BuildOpenAPISpecFromRoutes(restfuladapter.AdaptWebServices(restful.RegisteredWebServices()), config)
 	if err != nil {
 		panic(err)
 	}
@@ -977,6 +985,9 @@ func (app *virtAPIApp) startTLS(informerFactory controller.KubeInformerFactory)
 	server := &http.Server{
 		Addr:      fmt.Sprintf("%s:%d", app.BindAddress, app.Port),
 		TLSConfig: app.tlsConfig,
+		// Disable HTTP/2
+		// See CVE-2023-44487
+		TLSNextProto: map[string]func(*http.Server, *tls.Conn, http.Handler){},
 	}
 
 	// start TLS server
