@@ -38,7 +38,7 @@ import (
 
 	"kubevirt.io/kubevirt/pkg/testutils"
 	"kubevirt.io/kubevirt/pkg/virt-api/webhooks"
-	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
+	"kubevirt.io/kubevirt/pkg/virt-config/deprecation"
 )
 
 var _ = Describe("Validating MigrationCreate Admitter", func() {
@@ -95,7 +95,7 @@ var _ = Describe("Validating MigrationCreate Admitter", func() {
 			},
 		}
 		mockVMIClient.EXPECT().Get(context.Background(), inFlightMigration.Spec.VMIName, gomock.Any()).Return(vmi, nil)
-		migrationInterface.EXPECT().List(gomock.Any()).Return(kubecli.NewMigrationList(inFlightMigration), nil).AnyTimes()
+		migrationInterface.EXPECT().List(context.Background(), gomock.Any()).Return(kubecli.NewMigrationList(inFlightMigration), nil).AnyTimes()
 
 		migration := v1.VirtualMachineInstanceMigration{
 			ObjectMeta: metav1.ObjectMeta{
@@ -107,7 +107,7 @@ var _ = Describe("Validating MigrationCreate Admitter", func() {
 		}
 		migrationBytes, _ := json.Marshal(&migration)
 
-		enableFeatureGate(virtconfig.LiveMigrationGate)
+		enableFeatureGate(deprecation.LiveMigrationGate)
 
 		ar := &admissionv1.AdmissionReview{
 			Request: &admissionv1.AdmissionRequest{
@@ -125,7 +125,7 @@ var _ = Describe("Validating MigrationCreate Admitter", func() {
 	Context("with no conflicting migration", func() {
 
 		BeforeEach(func() {
-			migrationInterface.EXPECT().List(gomock.Any()).Return(&v1.VirtualMachineInstanceMigrationList{}, nil).MaxTimes(1)
+			migrationInterface.EXPECT().List(context.Background(), gomock.Any()).Return(&v1.VirtualMachineInstanceMigrationList{}, nil).MaxTimes(1)
 
 		})
 
@@ -144,7 +144,7 @@ var _ = Describe("Validating MigrationCreate Admitter", func() {
 			}
 			migrationBytes, _ := json.Marshal(&migration)
 
-			enableFeatureGate(virtconfig.LiveMigrationGate)
+			enableFeatureGate(deprecation.LiveMigrationGate)
 
 			ar := &admissionv1.AdmissionReview{
 				Request: &admissionv1.AdmissionRequest{
@@ -176,7 +176,7 @@ var _ = Describe("Validating MigrationCreate Admitter", func() {
 			}
 			migrationBytes, _ := json.Marshal(&migration)
 
-			enableFeatureGate(virtconfig.LiveMigrationGate)
+			enableFeatureGate(deprecation.LiveMigrationGate)
 
 			ar := &admissionv1.AdmissionReview{
 				Request: &admissionv1.AdmissionRequest{
@@ -211,7 +211,7 @@ var _ = Describe("Validating MigrationCreate Admitter", func() {
 			}
 			migrationBytes, _ := json.Marshal(&migration)
 
-			enableFeatureGate(virtconfig.LiveMigrationGate)
+			enableFeatureGate(deprecation.LiveMigrationGate)
 
 			ar := &admissionv1.AdmissionReview{
 				Request: &admissionv1.AdmissionRequest{
@@ -242,7 +242,7 @@ var _ = Describe("Validating MigrationCreate Admitter", func() {
 			}
 			migrationBytes, _ := json.Marshal(&migration)
 
-			enableFeatureGate(virtconfig.LiveMigrationGate)
+			enableFeatureGate(deprecation.LiveMigrationGate)
 
 			ar := &admissionv1.AdmissionReview{
 				Request: &admissionv1.AdmissionRequest{
@@ -285,7 +285,7 @@ var _ = Describe("Validating MigrationCreate Admitter", func() {
 			}
 			migrationBytes, _ := json.Marshal(&migration)
 
-			enableFeatureGate(virtconfig.LiveMigrationGate)
+			enableFeatureGate(deprecation.LiveMigrationGate)
 
 			ar := &admissionv1.AdmissionReview{
 				Request: &admissionv1.AdmissionRequest{
