@@ -24,27 +24,30 @@ import (
 	"encoding/json"
 	"fmt"
 
+	"k8s.io/apimachinery/pkg/api/resource"
+
+	"kubevirt.io/kubevirt/pkg/virt-launcher/virtwrap/converter"
+
 	corev1 "k8s.io/api/core/v1"
 
 	admissionv1 "k8s.io/api/admission/v1"
 	authv1 "k8s.io/api/authorization/v1"
 	"k8s.io/apimachinery/pkg/api/equality"
 	"k8s.io/apimachinery/pkg/api/errors"
-	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	k8sfield "k8s.io/apimachinery/pkg/util/validation/field"
 	"k8s.io/client-go/tools/cache"
 
-	"kubevirt.io/kubevirt/pkg/controller"
-	migrationutil "kubevirt.io/kubevirt/pkg/util/migrations"
-	"kubevirt.io/kubevirt/pkg/virt-launcher/virtwrap/converter"
-
 	v1 "kubevirt.io/api/core/v1"
 	instancetypev1beta1 "kubevirt.io/api/instancetype/v1beta1"
 	"kubevirt.io/client-go/kubecli"
 	cdiv1 "kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 
+	"kubevirt.io/kubevirt/pkg/controller"
+	migrationutil "kubevirt.io/kubevirt/pkg/util/migrations"
+
 	"kubevirt.io/kubevirt/pkg/instancetype"
+	metrics "kubevirt.io/kubevirt/pkg/monitoring/metrics/virt-api"
 	webhookutils "kubevirt.io/kubevirt/pkg/util/webhooks"
 	"kubevirt.io/kubevirt/pkg/virt-api/webhooks"
 	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
@@ -193,24 +196,16 @@ func (admitter *VMsAdmitter) Admit(ar *admissionv1.AdmissionReview) *admissionv1
 		return webhookutils.ToAdmissionResponse(causes)
 	}
 
-	if ar.Request.Operation == admissionv1.Update {
-		oldVM := v1.VirtualMachine{}
-		if err := json.Unmarshal(ar.Request.OldObject.Raw, &oldVM); err != nil {
-			return webhookutils.ToAdmissionResponseError(err)
-		}
-
-		if !equality.Semantic.DeepEqual(&oldVM.Spec, &vm.Spec) {
-			causes = admitter.validateVMUpdate(&oldVM, &vm)
-			if len(causes) > 0 {
-				return webhookutils.ToAdmissionResponse(causes)
-			}
-		}
+	isDryRun := ar.Request.DryRun != nil && *ar.Request.DryRun
+	if !isDryRun && ar.Request.Operation == admissionv1.Create {
+		metrics.NewVMCreated(&vm)
 	}
 
-	reviewResponse := admissionv1.AdmissionResponse{}
-	reviewResponse.Allowed = true
+	return &admissionv1.AdmissionResponse{
+		Allowed:  true,
+		Warnings: warnDeprecatedAPIs(&vm.Spec.Template.Spec, admitter.ClusterConfig),
+	}
 
-	return &reviewResponse
 }
 
 func (admitter *VMsAdmitter) AdmitStatus(ar *admissionv1.AdmissionReview) *admissionv1.AdmissionResponse {
@@ -260,11 +255,7 @@ func (admitter *VMsAdmitter) applyInstancetypeToVm(vm *v1.VirtualMachine) (*inst
 		}}
 	}
 
-	if instancetypeSpec == nil && preferenceSpec == nil {
-		return nil, nil, nil
-	}
-
-	if topology := instancetype.GetPreferredTopology(preferenceSpec); topology == instancetypev1beta1.PreferSpread {
+	if topology := instancetype.GetPreferredTopology(preferenceSpec); instancetypeSpec != nil && topology == instancetypev1beta1.PreferSpread {
 		ratio := preferenceSpec.PreferSpreadSocketToCoreRatio
 		if ratio == 0 {
 			ratio = instancetype.DefaultSpreadRatio
@@ -437,160 +428,115 @@ func validateRunStrategy(field *k8sfield.Path, spec *v1.VirtualMachineSpec) (cau
 }
 
 func validateLiveUpdateFeatures(field *k8sfield.Path, spec *v1.VirtualMachineSpec, config *virtconfig.ClusterConfig) (causes []metav1.StatusCause) {
-	if spec.LiveUpdateFeatures != nil && !config.VMLiveUpdateFeaturesEnabled() {
+	if !config.IsVMRolloutStrategyLiveUpdate() {
+		return causes
+	}
+
+	causes = append(causes, validateLiveUpdateCPU(field, &spec.Template.Spec.Domain)...)
+
+	if spec.Template.Spec.Domain.Memory != nil && spec.Template.Spec.Domain.Memory.MaxGuest != nil {
+		causes = append(causes, validateLiveUpdateMemory(field, &spec.Template.Spec.Domain, spec.Template.Spec.Architecture)...)
+	}
+
+	return causes
+}
+
+func validateLiveUpdateCPU(field *k8sfield.Path, domain *v1.DomainSpec) (causes []metav1.StatusCause) {
+	if domain.CPU.Sockets != 0 && domain.CPU.MaxSockets != 0 && domain.CPU.Sockets > domain.CPU.MaxSockets {
 		causes = append(causes, metav1.StatusCause{
 			Type:    metav1.CauseTypeFieldValueInvalid,
-			Message: fmt.Sprintf("%s feature gate is not enabled in kubevirt-config", virtconfig.VMLiveUpdateFeaturesGate),
-			Field:   field.Child("liveUpdateFeatures").String(),
+			Message: fmt.Sprintf("Number of sockets in CPU topology is greater than the maximum sockets allowed"),
+			Field:   field.Child("template", "spec", "domain", "cpu", "sockets").String(),
 		})
 	}
 
-	if spec.Template.Spec.Domain.CPU != nil && spec.Template.Spec.Domain.CPU.MaxSockets != 0 {
+	return causes
+}
+
+func validateLiveUpdateMemory(field *k8sfield.Path, domain *v1.DomainSpec, architecture string) (causes []metav1.StatusCause) {
+	if domain.CPU != nil &&
+		domain.CPU.Realtime != nil {
 		causes = append(causes, metav1.StatusCause{
-			Type:    metav1.CauseTypeFieldValueNotSupported,
-			Message: fmt.Sprintf("CPU topology maxSockets cannot be set directy in VM template"),
-			Field:   field.Child("template.spec.domain.cpu.maxSockets").String(),
+			Type:    metav1.CauseTypeFieldValueInvalid,
+			Message: fmt.Sprintf("Memory hotplug is not compatible with realtime VMs"),
+			Field:   field.Child("template", "spec", "domain", "cpu", "realtime").String(),
 		})
 	}
 
-	if spec.LiveUpdateFeatures != nil {
-		if spec.Instancetype != nil {
-			causes = append(causes, metav1.StatusCause{
-				Type:    metav1.CauseTypeFieldValueNotSupported,
-				Message: fmt.Sprintf("Live update features cannot be used when instance type is configured"),
-				Field:   field.Child("liveUpdateFeatures").String(),
-			})
-		}
-	}
-
-	if spec.LiveUpdateFeatures != nil && spec.LiveUpdateFeatures.CPU != nil {
-
-		if spec.Template.Spec.Domain.CPU.Sockets != 0 {
-			if spec.LiveUpdateFeatures.CPU.MaxSockets != nil {
-				if spec.Template.Spec.Domain.CPU.Sockets > *spec.LiveUpdateFeatures.CPU.MaxSockets {
-					causes = append(causes, metav1.StatusCause{
-						Type:    metav1.CauseTypeFieldValueInvalid,
-						Message: fmt.Sprintf("Number of sockets in CPU topology is greater than the maximum sockets allowed"),
-						Field:   field.Child("liveUpdateFeatures").String(),
-					})
-				}
-			}
-		}
-
-		if hasCPURequestsOrLimits(&spec.Template.Spec.Domain.Resources) {
-			causes = append(causes, metav1.StatusCause{
-				Type:    metav1.CauseTypeFieldValueInvalid,
-				Message: fmt.Sprintf("Configuration of CPU resource requirements is not allowed when CPU live update is enabled"),
-				Field:   field.Child("liveUpdateFeatures").String(),
-			})
-		}
-	}
-
-	// Validate Memory Hotplug
-	if spec.Template.Spec.Domain.Memory != nil && spec.Template.Spec.Domain.Memory.MaxGuest != nil {
+	if domain.CPU != nil &&
+		domain.CPU.NUMA != nil &&
+		domain.CPU.NUMA.GuestMappingPassthrough != nil {
 		causes = append(causes, metav1.StatusCause{
-			Type:    metav1.CauseTypeFieldValueNotSupported,
-			Message: fmt.Sprintf("Memory maxGuest cannot be set directy in VM template"),
-			Field:   field.Child("template.spec.domain.memory.maxGuest").String(),
+			Type:    metav1.CauseTypeFieldValueInvalid,
+			Message: fmt.Sprintf("Memory hotplug is not compatible with guest mapping passthrough"),
+			Field:   field.Child("template", "spec", "domain", "cpu", "numa", "guestMappingPassthrough").String(),
 		})
 	}
 
-	if spec.LiveUpdateFeatures != nil &&
-		spec.LiveUpdateFeatures.Memory != nil &&
-		spec.LiveUpdateFeatures.Memory.MaxGuest != nil {
+	if domain.LaunchSecurity != nil {
+		causes = append(causes, metav1.StatusCause{
+			Type:    metav1.CauseTypeFieldValueInvalid,
+			Message: fmt.Sprintf("Memory hotplug is not compatible with encrypted VMs"),
+			Field:   field.Child("template", "spec", "domain", "launchSecurity").String(),
+		})
+	}
 
-		if hasMemoryLimits(&spec.Template.Spec.Domain.Resources) {
-			causes = append(causes, metav1.StatusCause{
-				Type:    metav1.CauseTypeFieldValueInvalid,
-				Message: fmt.Sprintf("Configuration of Memory limits is not allowed when Memory live update is enabled"),
-				Field:   field.Child("liveUpdateFeatures").String(),
-			})
-		}
+	if domain.CPU != nil &&
+		domain.CPU.DedicatedCPUPlacement {
+		causes = append(causes, metav1.StatusCause{
+			Type:    metav1.CauseTypeFieldValueInvalid,
+			Message: fmt.Sprintf("Memory hotplug is not compatible with dedicated CPUs"),
+			Field:   field.Child("template", "spec", "domain", "cpu", "dedicatedCpuPlacement").String(),
+		})
+	}
 
-		if spec.Template.Spec.Domain.CPU != nil &&
-			spec.Template.Spec.Domain.CPU.Realtime != nil {
-			causes = append(causes, metav1.StatusCause{
-				Type:    metav1.CauseTypeFieldValueInvalid,
-				Message: fmt.Sprintf("Memory hotplug is not compatible with realtime VMs"),
-				Field:   field.Child("template", "spec", "domain", "cpu", "realtime").String(),
-			})
-		}
+	if domain.Memory != nil &&
+		domain.Memory.Hugepages != nil {
+		causes = append(causes, metav1.StatusCause{
+			Type:    metav1.CauseTypeFieldValueInvalid,
+			Message: fmt.Sprintf("Memory hotplug is not compatible with hugepages"),
+			Field:   field.Child("template", "spec", "domain", "memory", "hugepages").String(),
+		})
+	}
 
-		if spec.Template.Spec.Domain.CPU != nil &&
-			spec.Template.Spec.Domain.CPU.NUMA != nil &&
-			spec.Template.Spec.Domain.CPU.NUMA.GuestMappingPassthrough != nil {
-			causes = append(causes, metav1.StatusCause{
-				Type:    metav1.CauseTypeFieldValueInvalid,
-				Message: fmt.Sprintf("Memory hotplug is not compatible with guest mapping passthrough"),
-				Field:   field.Child("template", "spec", "domain", "cpu", "numa", "guestMappingPassthrough").String(),
-			})
-		}
+	if domain.Memory == nil ||
+		domain.Memory.Guest == nil {
+		causes = append(causes, metav1.StatusCause{
+			Type:    metav1.CauseTypeFieldValueInvalid,
+			Message: fmt.Sprintf("Guest memory must be configured when memory hotplug is enabled"),
+			Field:   field.Child("template", "spec", "domain", "memory", "guest").String(),
+		})
+	} else if domain.Memory.Guest.Cmp(*domain.Memory.MaxGuest) > 0 {
+		causes = append(causes, metav1.StatusCause{
+			Type:    metav1.CauseTypeFieldValueInvalid,
+			Message: fmt.Sprintf("Guest memory is greater than the configured maxGuest memory"),
+			Field:   field.Child("template", "spec", "domain", "memory", "guest").String(),
+		})
+	} else if domain.Memory.Guest.Value()%converter.MemoryHotplugBlockAlignmentBytes != 0 {
+		alignment := resource.NewQuantity(converter.MemoryHotplugBlockAlignmentBytes, resource.BinarySI)
+		causes = append(causes, metav1.StatusCause{
+			Type:    metav1.CauseTypeFieldValueInvalid,
+			Message: fmt.Sprintf("Guest memory must be %s aligned", alignment),
+			Field:   field.Child("template", "spec", "domain", "memory", "guest").String(),
+		})
+	}
 
-		if spec.Template.Spec.Domain.LaunchSecurity != nil {
-			causes = append(causes, metav1.StatusCause{
-				Type:    metav1.CauseTypeFieldValueInvalid,
-				Message: fmt.Sprintf("Memory hotplug is not compatible with encrypted VMs"),
-				Field:   field.Child("template", "spec", "domain", "launchSecurity").String(),
-			})
-		}
-
-		if spec.Template.Spec.Domain.CPU != nil &&
-			spec.Template.Spec.Domain.CPU.DedicatedCPUPlacement {
-			causes = append(causes, metav1.StatusCause{
-				Type:    metav1.CauseTypeFieldValueInvalid,
-				Message: fmt.Sprintf("Memory hotplug is not compatible with dedicated CPUs"),
-				Field:   field.Child("template", "spec", "domain", "cpu", "dedicatedCpuPlacement").String(),
-			})
-		}
-
-		if spec.Template.Spec.Domain.Memory != nil &&
-			spec.Template.Spec.Domain.Memory.Hugepages != nil {
-			causes = append(causes, metav1.StatusCause{
-				Type:    metav1.CauseTypeFieldValueInvalid,
-				Message: fmt.Sprintf("Memory hotplug is not compatible with hugepages"),
-				Field:   field.Child("template", "spec", "domain", "memory", "hugepages").String(),
-			})
-		}
-
-		if spec.Template.Spec.Domain.Memory == nil ||
-			spec.Template.Spec.Domain.Memory.Guest == nil {
-			causes = append(causes, metav1.StatusCause{
-				Type:    metav1.CauseTypeFieldValueInvalid,
-				Message: fmt.Sprintf("Guest memory must be configured when memory hotplug is enabled"),
-				Field:   field.Child("template", "spec", "domain", "memory", "guest").String(),
-			})
-		} else if spec.Template.Spec.Domain.Memory.Guest.Cmp(*spec.LiveUpdateFeatures.Memory.MaxGuest) > 0 {
-			causes = append(causes, metav1.StatusCause{
-				Type:    metav1.CauseTypeFieldValueInvalid,
-				Message: fmt.Sprintf("Guest memory is greater than the configured maxGuest memory"),
-				Field:   field.Child("template", "spec", "domain", "memory", "guest").String(),
-			})
-		} else if spec.Template.Spec.Domain.Memory.Guest.Value()%converter.MemoryHotplugBlockAlignmentBytes != 0 {
-			alignment := resource.NewQuantity(converter.MemoryHotplugBlockAlignmentBytes, resource.BinarySI)
-			causes = append(causes, metav1.StatusCause{
-				Type:    metav1.CauseTypeFieldValueInvalid,
-				Message: fmt.Sprintf("Guest memory must be %s aligned", alignment),
-				Field:   field.Child("template", "spec", "domain", "memory", "guest").String(),
-			})
-		}
-
-		if spec.LiveUpdateFeatures.Memory.MaxGuest.Value()%converter.MemoryHotplugBlockAlignmentBytes != 0 {
-			alignment := resource.NewQuantity(converter.MemoryHotplugBlockAlignmentBytes, resource.BinarySI)
-			causes = append(causes, metav1.StatusCause{
-				Type:    metav1.CauseTypeFieldValueInvalid,
-				Message: fmt.Sprintf("MaxGuest must be %s aligned", alignment),
-				Field:   field.Child("liveUpdateFeatures", "MaxGuest").String(),
-			})
-		}
-
-		if spec.Template.Spec.Architecture != "amd64" {
-			causes = append(causes, metav1.StatusCause{
-				Type:    metav1.CauseTypeFieldValueInvalid,
-				Message: fmt.Sprintf("Memory hotplug is only available for x86_64 VMs"),
-				Field:   field.Child("template", "spec", "architecture").String(),
-			})
-		}
+	if domain.Memory.MaxGuest.Value()%converter.MemoryHotplugBlockAlignmentBytes != 0 {
+		alignment := resource.NewQuantity(converter.MemoryHotplugBlockAlignmentBytes, resource.BinarySI)
+		causes = append(causes, metav1.StatusCause{
+			Type:    metav1.CauseTypeFieldValueInvalid,
+			Message: fmt.Sprintf("MaxGuest must be %s aligned", alignment),
+			Field:   field.Child("template", "spec", "domain", "memory", "maxGuest").String(),
+		})
+	}
 
+	if architecture != "amd64" {
+		causes = append(causes, metav1.StatusCause{
+			Type:    metav1.CauseTypeFieldValueInvalid,
+			Message: fmt.Sprintf("Memory hotplug is only available for x86_64 VMs"),
+			Field:   field.Child("template", "spec", "architecture").String(),
+		})
+		return causes
 	}
 
 	return causes
@@ -614,7 +560,7 @@ func (admitter *VMsAdmitter) validateVolumeRequests(vm *v1.VirtualMachine) ([]me
 	if vm.Status.Ready {
 		var err error
 
-		vmi, err = admitter.VirtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, &metav1.GetOptions{})
+		vmi, err = admitter.VirtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
 		if err != nil && !errors.IsNotFound(err) {
 			return nil, err
 		} else if err == nil && vmi.DeletionTimestamp == nil {
@@ -743,6 +689,7 @@ func (admitter *VMsAdmitter) validateVolumeRequests(vm *v1.VirtualMachine) ([]me
 }
 
 func validateDiskConfiguration(disk *v1.Disk, name string) []metav1.StatusCause {
+	var bus v1.DiskBus
 	// Validate the disk is configured properly
 	if disk == nil {
 		return []metav1.StatusCause{{
@@ -750,16 +697,30 @@ func validateDiskConfiguration(disk *v1.Disk, name string) []metav1.StatusCause
 			Message: fmt.Sprintf("AddVolume request for [%s] requires the disk field to be set.", name),
 			Field:   k8sfield.NewPath("Status", "volumeRequests").String(),
 		}}
-	} else if disk.DiskDevice.Disk == nil {
+	}
+	if disk.DiskDevice.Disk == nil && disk.DiskDevice.LUN == nil {
 		return []metav1.StatusCause{{
 			Type:    metav1.CauseTypeFieldValueInvalid,
-			Message: fmt.Sprintf("AddVolume request for [%s] requires diskDevice of type 'disk' to be used.", name),
+			Message: fmt.Sprintf("AddVolume request for [%s] requires diskDevice of type 'disk' or 'lun' to be used.", name),
 			Field:   k8sfield.NewPath("Status", "volumeRequests").String(),
 		}}
-	} else if disk.DiskDevice.Disk.Bus != "scsi" {
+	}
+	if disk.DiskDevice.Disk != nil {
+		bus = disk.DiskDevice.Disk.Bus
+	} else {
+		bus = disk.DiskDevice.LUN.Bus
+	}
+	if bus != "scsi" {
 		return []metav1.StatusCause{{
 			Type:    metav1.CauseTypeFieldValueInvalid,
-			Message: fmt.Sprintf("AddVolume request for [%s] requires disk bus to be 'scsi'. [%s] is not permitted", name, disk.DiskDevice.Disk.Bus),
+			Message: fmt.Sprintf("AddVolume request for [%s] requires disk bus to be 'scsi'. [%s] is not permitted", name, bus),
+			Field:   k8sfield.NewPath("Status", "volumeRequests").String(),
+		}}
+	}
+	if disk.DedicatedIOThread != nil && *disk.DedicatedIOThread {
+		return []metav1.StatusCause{{
+			Type:    metav1.CauseTypeFieldValueInvalid,
+			Message: "IOThreads are not supported by scsi bus.",
 			Field:   k8sfield.NewPath("Status", "volumeRequests").String(),
 		}}
 	}
@@ -818,113 +779,6 @@ func validateSnapshotStatus(ar *admissionv1.AdmissionRequest, vm *v1.VirtualMach
 	return nil
 }
 
-func (admitter *VMsAdmitter) validateVMUpdate(oldVM, newVM *v1.VirtualMachine) []metav1.StatusCause {
-	if newVM.Status.Ready {
-		if !equality.Semantic.DeepEqual(&oldVM.Spec.LiveUpdateFeatures, &newVM.Spec.LiveUpdateFeatures) {
-			return []metav1.StatusCause{{
-				Type:    metav1.CauseTypeFieldValueNotSupported,
-				Message: fmt.Sprintf("Cannot update VM live features while VM is running"),
-				Field:   k8sfield.NewPath("spec").String(),
-			}}
-		}
-
-		if newVM.Spec.LiveUpdateFeatures != nil {
-
-			// CPU hotplug
-			if newVM.Spec.LiveUpdateFeatures.CPU != nil {
-				oldTopology := oldVM.Spec.Template.Spec.Domain.CPU
-				newTopology := newVM.Spec.Template.Spec.Domain.CPU
-				if oldTopology != nil && newTopology != nil {
-					if oldTopology.Cores != newTopology.Cores {
-						return []metav1.StatusCause{{
-							Type:    metav1.CauseTypeFieldValueNotSupported,
-							Message: fmt.Sprintf("Cannot update CPU cores while live update features configured"),
-							Field:   k8sfield.NewPath("spec.template.spec.domain.cpu.cores").String(),
-						}}
-					}
-					if oldTopology.Threads != newTopology.Threads {
-						return []metav1.StatusCause{{
-							Type:    metav1.CauseTypeFieldValueNotSupported,
-							Message: fmt.Sprintf("Cannot update CPU threads while live update features configured"),
-							Field:   k8sfield.NewPath("spec.template.spec.domain.cpu.threads").String(),
-						}}
-					}
-					if oldTopology.Sockets != newTopology.Sockets {
-						if causeErr := admitter.shouldAllowCPUHotPlug(oldVM); causeErr != nil {
-							return []metav1.StatusCause{{
-								Type:    metav1.CauseTypeFieldValueNotSupported,
-								Message: causeErr.Error(),
-								Field:   k8sfield.NewPath("spec.template.spec.domain.cpu.sockets").String(),
-							}}
-						}
-
-					}
-				}
-			}
-
-			// Memory Hotplug
-			if newVM.Spec.LiveUpdateFeatures.Memory != nil {
-				oldGuestMemory := oldVM.Spec.Template.Spec.Domain.Memory.Guest
-				newGuestMemory := newVM.Spec.Template.Spec.Domain.Memory.Guest
-
-				if !oldGuestMemory.Equal(*newGuestMemory) {
-					if causeErr := admitter.shouldAllowMemoryHotPlug(newVM); causeErr != nil {
-						return []metav1.StatusCause{{
-							Type:    metav1.CauseTypeFieldValueNotSupported,
-							Message: causeErr.Error(),
-							Field:   k8sfield.NewPath("spec.template.spec.domain.memory.guest").String(),
-						}}
-					}
-				}
-			}
-		}
-	}
-
-	return nil
-}
-
-func (admitter *VMsAdmitter) shouldAllowCPUHotPlug(vm *v1.VirtualMachine) error {
-	vmi, err := admitter.VirtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, &metav1.GetOptions{})
-	if err != nil {
-		return err
-	}
-
-	for _, c := range vmi.Status.Conditions {
-		if c.Type == v1.VirtualMachineInstanceVCPUChange &&
-			c.Status == corev1.ConditionTrue {
-			return fmt.Errorf("cannot update CPU sockets while another CPU change is in progress")
-		}
-	}
-
-	if err := admitter.isMigrationInProgress(vmi); err != nil {
-		return err
-	}
-	return nil
-}
-
-func (admitter *VMsAdmitter) shouldAllowMemoryHotPlug(vm *v1.VirtualMachine) error {
-	vmi, err := admitter.VirtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, &metav1.GetOptions{})
-	if err != nil {
-		return err
-	}
-
-	if vm.Spec.Template.Spec.Domain.Memory.Guest.Cmp(*vmi.Status.Memory.GuestAtBoot) < 0 {
-		return fmt.Errorf("cannot set less memory than what the guest booted with")
-	}
-
-	for _, c := range vmi.Status.Conditions {
-		if c.Type == v1.VirtualMachineInstanceMemoryChange &&
-			c.Status == corev1.ConditionTrue {
-			return fmt.Errorf("cannot update memory while another memory change is in progress")
-		}
-	}
-
-	if err := admitter.isMigrationInProgress(vmi); err != nil {
-		return err
-	}
-	return nil
-}
-
 func (admitter *VMsAdmitter) isMigrationInProgress(vmi *v1.VirtualMachineInstance) error {
 	if vmi.Status.MigrationState != nil &&
 		!vmi.Status.MigrationState.Completed {
@@ -937,19 +791,3 @@ func (admitter *VMsAdmitter) isMigrationInProgress(vmi *v1.VirtualMachineInstanc
 	}
 	return nil
 }
-
-func hasCPURequestsOrLimits(rr *v1.ResourceRequirements) bool {
-	if _, ok := rr.Requests[corev1.ResourceCPU]; ok {
-		return true
-	}
-	if _, ok := rr.Limits[corev1.ResourceCPU]; ok {
-		return true
-	}
-
-	return false
-}
-
-func hasMemoryLimits(rr *v1.ResourceRequirements) bool {
-	_, ok := rr.Limits[corev1.ResourceMemory]
-	return ok
-}
