@@ -43,7 +43,7 @@ import (
 	k8sfake "k8s.io/client-go/kubernetes/fake"
 	"k8s.io/client-go/testing"
 	"k8s.io/client-go/tools/cache"
-
+	k8sptr "k8s.io/utils/pointer"
 	instancetypeapi "kubevirt.io/api/instancetype"
 	instancetypev1beta1 "kubevirt.io/api/instancetype/v1beta1"
 
@@ -55,6 +55,7 @@ import (
 	"kubevirt.io/kubevirt/pkg/testutils"
 	"kubevirt.io/kubevirt/pkg/virt-api/webhooks"
 	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
+	"kubevirt.io/kubevirt/pkg/virt-config/deprecation"
 	"kubevirt.io/kubevirt/pkg/virt-launcher/virtwrap/converter"
 
 	rt "runtime"
@@ -67,33 +68,39 @@ var _ = Describe("Validating VM Admitter", func() {
 		dataSourceInformer  cache.SharedIndexInformer
 		namespaceInformer   cache.SharedIndexInformer
 		instancetypeMethods *testutils.MockInstancetypeMethods
-		migrationInterface  *kubecli.MockVirtualMachineInstanceMigrationInterface
 		mockVMIClient       *kubecli.MockVirtualMachineInstanceInterface
 		virtClient          *kubecli.MockKubevirtClient
 		k8sClient           *k8sfake.Clientset
 	)
 
 	enableFeatureGate := func(featureGates ...string) {
-		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, &v1.KubeVirt{
-			Spec: v1.KubeVirtSpec{
-				Configuration: v1.KubeVirtConfiguration{
-					DeveloperConfiguration: &v1.DeveloperConfiguration{
-						FeatureGates: featureGates,
-					},
-				},
-			},
-		})
+		kv := testutils.GetFakeKubeVirtClusterConfig(kvInformer)
+		if kv.Spec.Configuration.DeveloperConfiguration == nil {
+			kv.Spec.Configuration.DeveloperConfiguration = &v1.DeveloperConfiguration{}
+		}
+		if kv.Spec.Configuration.DeveloperConfiguration.FeatureGates == nil {
+			kv.Spec.Configuration.DeveloperConfiguration.FeatureGates = featureGates
+		} else {
+			kv.Spec.Configuration.DeveloperConfiguration.FeatureGates = append(kv.Spec.Configuration.DeveloperConfiguration.FeatureGates, featureGates...)
+		}
+		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, kv)
 	}
 	disableFeatureGates := func() {
-		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, &v1.KubeVirt{
-			Spec: v1.KubeVirtSpec{
-				Configuration: v1.KubeVirtConfiguration{
-					DeveloperConfiguration: &v1.DeveloperConfiguration{
-						FeatureGates: make([]string, 0),
-					},
-				},
-			},
-		})
+		kv := testutils.GetFakeKubeVirtClusterConfig(kvInformer)
+		if kv.Spec.Configuration.DeveloperConfiguration != nil {
+			kv.Spec.Configuration.DeveloperConfiguration.FeatureGates = make([]string, 0)
+		}
+		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, kv)
+	}
+	enableLiveUpdate := func() {
+		kv := testutils.GetFakeKubeVirtClusterConfig(kvInformer)
+		kv.Spec.Configuration.VMRolloutStrategy = pointer.P(v1.VMRolloutStrategyLiveUpdate)
+		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, kv)
+	}
+	disableLiveUpdate := func() {
+		kv := testutils.GetFakeKubeVirtClusterConfig(kvInformer)
+		kv.Spec.Configuration.VMRolloutStrategy = nil
+		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, kv)
 	}
 
 	notRunning := false
@@ -125,7 +132,6 @@ var _ = Describe("Validating VM Admitter", func() {
 
 		ctrl := gomock.NewController(GinkgoT())
 		mockVMIClient = kubecli.NewMockVirtualMachineInstanceInterface(ctrl)
-		migrationInterface = kubecli.NewMockVirtualMachineInstanceMigrationInterface(ctrl)
 		k8sClient = k8sfake.NewSimpleClientset()
 		virtClient = kubecli.NewMockKubevirtClient(ctrl)
 		vmsAdmitter = &VMsAdmitter{
@@ -432,6 +438,92 @@ var _ = Describe("Validating VM Admitter", func() {
 			},
 		},
 			true),
+		Entry("with valid request to add volume to a LUN disk", []v1.VirtualMachineVolumeRequest{
+			{
+				AddVolumeOptions: &v1.AddVolumeOptions{
+					Name: "testlun2",
+					Disk: &v1.Disk{
+						Name: "testlun2",
+						DiskDevice: v1.DiskDevice{
+							LUN: &v1.LunTarget{
+								Bus: "scsi",
+							},
+						},
+					},
+					VolumeSource: &v1.HotplugVolumeSource{
+						PersistentVolumeClaim: &v1.PersistentVolumeClaimVolumeSource{PersistentVolumeClaimVolumeSource: k8sv1.PersistentVolumeClaimVolumeSource{
+							ClaimName: "madeupLUN",
+						},
+						},
+					},
+				},
+			},
+		},
+			true),
+		Entry("with invalid request to add volume with invalid disk/bus combination", []v1.VirtualMachineVolumeRequest{
+			{
+				AddVolumeOptions: &v1.AddVolumeOptions{
+					Name: "testLUN-usb",
+					Disk: &v1.Disk{
+						Name: "testLUN-usb",
+						DiskDevice: v1.DiskDevice{
+							LUN: &v1.LunTarget{
+								Bus: "usb",
+							},
+						},
+					},
+					VolumeSource: &v1.HotplugVolumeSource{
+						PersistentVolumeClaim: &v1.PersistentVolumeClaimVolumeSource{PersistentVolumeClaimVolumeSource: k8sv1.PersistentVolumeClaimVolumeSource{
+							ClaimName: "invalidCombination",
+						}},
+					},
+				},
+			},
+		},
+			false),
+		Entry("with invalid request to add volume with invalid disk type", []v1.VirtualMachineVolumeRequest{
+			{
+				AddVolumeOptions: &v1.AddVolumeOptions{
+					Name: "testCDRom",
+					Disk: &v1.Disk{
+						Name: "testCDRom",
+						DiskDevice: v1.DiskDevice{
+							CDRom: &v1.CDRomTarget{
+								Bus: "scsi",
+							},
+						},
+					},
+					VolumeSource: &v1.HotplugVolumeSource{
+						PersistentVolumeClaim: &v1.PersistentVolumeClaimVolumeSource{PersistentVolumeClaimVolumeSource: k8sv1.PersistentVolumeClaimVolumeSource{
+							ClaimName: "cdRomtest",
+						}},
+					},
+				},
+			},
+		},
+			false),
+		Entry("with invalid request to add volume with dedicated IOThreads", []v1.VirtualMachineVolumeRequest{
+			{
+				AddVolumeOptions: &v1.AddVolumeOptions{
+					Name: "testDisk",
+					Disk: &v1.Disk{
+						Name: "testDisk",
+						DiskDevice: v1.DiskDevice{
+							Disk: &v1.DiskTarget{
+								Bus: "scsi",
+							},
+						},
+						DedicatedIOThread: k8sptr.BoolPtr(true),
+					},
+					VolumeSource: &v1.HotplugVolumeSource{
+						PersistentVolumeClaim: &v1.PersistentVolumeClaimVolumeSource{PersistentVolumeClaimVolumeSource: k8sv1.PersistentVolumeClaimVolumeSource{
+							ClaimName: "diskTest",
+						}},
+					},
+				},
+			},
+		},
+			false),
 		Entry("with invalid request to add volume that conflicts with running vmi", []v1.VirtualMachineVolumeRequest{
 			{
 				AddVolumeOptions: &v1.AddVolumeOptions{
@@ -940,7 +1032,7 @@ var _ = Describe("Validating VM Admitter", func() {
 			Entry("with secret volume source", v1.VolumeSource{Secret: &v1.SecretVolumeSource{SecretName: "fake"}}),
 			Entry("with serviceAccount volume source", v1.VolumeSource{ServiceAccount: &v1.ServiceAccountVolumeSource{ServiceAccountName: "fake"}}),
 		)
-		It("should reject DataVolume when feature gate is disabled", func() {
+		It("should allow create a vm using a DataVolume when cdi doesnt exist", func() {
 			vmi := api.NewMinimalVMI("testvmi")
 
 			vmi.Spec.Volumes = append(vmi.Spec.Volumes, v1.Volume{
@@ -950,8 +1042,7 @@ var _ = Describe("Validating VM Admitter", func() {
 
 			testutils.RemoveDataVolumeAPI(crdInformer)
 			causes := validateVolumes(k8sfield.NewPath("fake"), vmi.Spec.Volumes, config)
-			Expect(causes).To(HaveLen(1))
-			Expect(causes[0].Field).To(Equal("fake[0]"))
+			Expect(causes).To(BeEmpty())
 		})
 		It("should reject DataVolume when DataVolume name is not set", func() {
 			vmi := api.NewMinimalVMI("testvmi")
@@ -1402,7 +1493,8 @@ var _ = Describe("Validating VM Admitter", func() {
 				Namespace: arNamespace,
 			}
 
-			vmsAdmitter.DataSourceInformer.GetIndexer().Add(ds)
+			err := vmsAdmitter.DataSourceInformer.GetIndexer().Add(ds)
+			Expect(err).NotTo(HaveOccurred())
 
 			vmsAdmitter.cloneAuthFunc = makeCloneAdmitFunc(k8sClient, expectedSourceNamespace,
 				"whocares",
@@ -1747,18 +1839,27 @@ var _ = Describe("Validating VM Admitter", func() {
 			Entry("default PreferSpreadSocketToCoreRatio", 3, 0),
 			Entry("odd PreferSpreadSocketToCoreRatio", 8, 3),
 		)
+
+		It("should admit VM with preference using preferSpread and without instancetype", func() {
+			vm.Spec.Instancetype = nil
+			instancetypeMethods.FindPreferenceSpecFunc = func(_ *v1.VirtualMachine) (*instancetypev1beta1.VirtualMachinePreferenceSpec, error) {
+				return &instancetypev1beta1.VirtualMachinePreferenceSpec{CPU: &instancetypev1beta1.CPUPreferences{PreferredCPUTopology: pointer.P(instancetypev1beta1.PreferSpread)}}, nil
+			}
+			response := admitVm(vmsAdmitter, vm)
+			Expect(response.Allowed).To(BeTrue())
+		})
 	})
 
-	Context("Live update features", func() {
+	Context("Live update", func() {
 		var vm *v1.VirtualMachine
 
 		BeforeEach(func() {
 			vmi := api.NewMinimalVMI("testvmi")
 			enableFeatureGate(virtconfig.VMLiveUpdateFeaturesGate)
+			enableLiveUpdate()
 			vm = &v1.VirtualMachine{
 				Spec: v1.VirtualMachineSpec{
-					LiveUpdateFeatures: &v1.LiveUpdateFeatures{},
-					Running:            &notRunning,
+					Running: &notRunning,
 					Template: &v1.VirtualMachineInstanceTemplateSpec{
 						Spec: vmi.Spec,
 					},
@@ -1766,333 +1867,32 @@ var _ = Describe("Validating VM Admitter", func() {
 			}
 		})
 
-		DescribeTable("should be rejected when the feature gate is disabled", func(mutateSpec func(*v1.VirtualMachineSpec)) {
+		AfterEach(func() {
+			disableLiveUpdate()
 			disableFeatureGates()
-			mutateSpec(&vm.Spec)
-			response := admitVm(vmsAdmitter, vm)
-			Expect(response.Allowed).To(BeFalse())
-			Expect(response.Result.Details.Causes).To(HaveLen(1))
-			Expect(response.Result.Details.Causes[0].Field).To(Equal("spec.liveUpdateFeatures"))
-			Expect(response.Result.Details.Causes[0].Message).To(ContainSubstring(fmt.Sprintf("%s feature gate is not enabled", virtconfig.VMLiveUpdateFeaturesGate)))
-		},
-			Entry("and CPU hotplug is enabled", func(spec *v1.VirtualMachineSpec) {
-				spec.LiveUpdateFeatures.CPU = &v1.LiveUpdateCPU{}
-			}),
-			Entry("and Memory hotplug is enabled", func(spec *v1.VirtualMachineSpec) {
-				spec.LiveUpdateFeatures.Memory = &v1.LiveUpdateMemory{}
-			}),
-		)
-
-		DescribeTable("should reject VM creation when VM has instance type assigned", func(mutateSpec func(*v1.VirtualMachineSpec)) {
-			mutateSpec(&vm.Spec)
-			vm.Spec.Instancetype = &v1.InstancetypeMatcher{
-				Name: "foobar",
-			}
-			response := admitVm(vmsAdmitter, vm)
-			Expect(response.Allowed).To(BeFalse())
-			Expect(response.Result.Details.Causes[0].Field).To(Equal("spec.liveUpdateFeatures"))
-			Expect(response.Result.Details.Causes[0].Message).To(ContainSubstring("Live update features cannot be used when instance type is configured"))
-		},
-			Entry("and CPU hotplug is enabled", func(spec *v1.VirtualMachineSpec) {
-				spec.LiveUpdateFeatures.CPU = &v1.LiveUpdateCPU{}
-			}),
-			Entry("and Memory hotplug is enabled", func(spec *v1.VirtualMachineSpec) {
-				spec.LiveUpdateFeatures.Memory = &v1.LiveUpdateMemory{}
-			}),
-		)
+		})
 
 		Context("CPU", func() {
 			const maximumSockets uint32 = 24
 
 			BeforeEach(func() {
-				vm.Spec.LiveUpdateFeatures.CPU = &v1.LiveUpdateCPU{
-					MaxSockets: pointer.P(maximumSockets),
-				}
-			})
-
-			It("should reject configuration of maxSockets in VM template", func() {
 				vm.Spec.Template.Spec.Domain.CPU = &v1.CPU{
-					MaxSockets: 1,
+					MaxSockets: maximumSockets,
 				}
-
-				response := admitVm(vmsAdmitter, vm)
-				Expect(response.Allowed).To(BeFalse())
-				Expect(response.Result.Details.Causes[0].Field).To(Equal("spec.template.spec.domain.cpu.maxSockets"))
-				Expect(response.Result.Details.Causes[0].Message).To(ContainSubstring(""))
 			})
 
 			It("should reject VM creation when number of sockets exceeds the maximum configured", func() {
-				vm.Spec.Template.Spec.Domain.CPU = &v1.CPU{
-					Sockets: maximumSockets + 1,
-				}
+				vm.Spec.Template.Spec.Domain.CPU.Sockets = maximumSockets + 1
 				response := admitVm(vmsAdmitter, vm)
 				Expect(response.Allowed).To(BeFalse())
-				Expect(response.Result.Details.Causes[0].Field).To(Equal("spec.liveUpdateFeatures"))
+				Expect(response.Result.Details.Causes[0].Field).To(Equal("spec.template.spec.domain.cpu.sockets"))
 				Expect(response.Result.Details.Causes[0].Message).To(ContainSubstring("Number of sockets in CPU topology is greater than the maximum sockets allowed"))
 			})
 
-			It("should reject VM creation when resource requests are configured", func() {
-				vm.Spec.Template.Spec.Domain.Resources.Requests = make(k8sv1.ResourceList)
-				vm.Spec.Template.Spec.Domain.Resources.Requests[k8sv1.ResourceCPU] = resource.MustParse("400m")
-
-				response := admitVm(vmsAdmitter, vm)
-				Expect(response.Allowed).To(BeFalse())
-				Expect(response.Result.Details.Causes[0].Field).To(Equal("spec.liveUpdateFeatures"))
-				Expect(response.Result.Details.Causes[0].Message).To(ContainSubstring("Configuration of CPU resource requirements is not allowed when CPU live update is enabled"))
-			})
-
-			It("should reject VM creation when resource limits are configured", func() {
-				vm.Spec.Template.Spec.Domain.Resources.Limits = make(k8sv1.ResourceList)
-				vm.Spec.Template.Spec.Domain.Resources.Limits[k8sv1.ResourceCPU] = resource.MustParse("400m")
-
-				response := admitVm(vmsAdmitter, vm)
-				Expect(response.Allowed).To(BeFalse())
-				Expect(response.Result.Details.Causes[0].Field).To(Equal("spec.liveUpdateFeatures"))
-				Expect(response.Result.Details.Causes[0].Message).To(ContainSubstring("Configuration of CPU resource requirements is not allowed when CPU live update is enabled"))
-			})
-
 			When("Hot CPU change is in progress", func() {
 				BeforeEach(func() {
 					vm.Status.Ready = true
 				})
-
-				It("should reject updating CPU sockets while CPU hot update is enabled ", func() {
-					vmi := api.NewMinimalVMI("testvmi")
-					newCondition := v1.VirtualMachineInstanceCondition{
-						Type:               v1.VirtualMachineInstanceVCPUChange,
-						LastTransitionTime: metav1.Now(),
-						Status:             k8sv1.ConditionTrue,
-					}
-					vmi.Status.Conditions = append(vmi.Status.Conditions, newCondition)
-					vm.ObjectMeta = metav1.ObjectMeta{
-						Name:      vmi.Name,
-						Namespace: vmi.Namespace,
-					}
-
-					vm.Spec.Template.Spec.Domain.CPU = &v1.CPU{
-						Cores:   2,
-						Sockets: 1,
-					}
-					oldVMBytes, err := json.Marshal(&vm)
-					Expect(err).ToNot(HaveOccurred())
-
-					vm.Spec.Template.Spec.Domain.CPU.Sockets++
-					newVMBytes, err := json.Marshal(&vm)
-					Expect(err).ToNot(HaveOccurred())
-
-					ar := &admissionv1.AdmissionReview{
-						Request: &admissionv1.AdmissionRequest{
-							Resource: webhooks.VirtualMachineGroupVersionResource,
-							Object: runtime.RawExtension{
-								Raw: newVMBytes,
-							},
-							OldObject: runtime.RawExtension{
-								Raw: oldVMBytes,
-							},
-							Operation: admissionv1.Update,
-						},
-					}
-
-					virtClient.EXPECT().VirtualMachineInstance(gomock.Any()).Return(mockVMIClient)
-					mockVMIClient.EXPECT().Get(context.Background(), vmi.Name, gomock.Any()).Return(vmi, nil)
-					response := vmsAdmitter.Admit(ar)
-					Expect(response.Allowed).To(BeFalse())
-					Expect(response.Result.Details.Causes[0].Field).To(Equal("spec.template.spec.domain.cpu.sockets"))
-					Expect(response.Result.Details.Causes[0].Message).To(ContainSubstring("cannot update CPU sockets while another CPU change is in progress"))
-				})
-			})
-			When("VMI is migratng", func() {
-
-				BeforeEach(func() {
-					vm.Status = v1.VirtualMachineStatus{
-						Ready: true,
-					}
-				})
-				It("should reject updating CPU Sockets while VMI is migrating ", func() {
-					now := metav1.Now()
-					vmi := api.NewMinimalVMI("testvmi")
-					vmi.Status = v1.VirtualMachineInstanceStatus{
-						MigrationState: &v1.VirtualMachineInstanceMigrationState{
-							StartTimestamp: &now,
-						},
-					}
-					vm.ObjectMeta = metav1.ObjectMeta{
-						Name:      vmi.Name,
-						Namespace: vmi.Namespace,
-					}
-					vm.Spec.Template.Spec.Domain.CPU = &v1.CPU{
-						Cores:   2,
-						Sockets: 1,
-					}
-					oldVMBytes, err := json.Marshal(&vm)
-					Expect(err).ToNot(HaveOccurred())
-
-					vm.Spec.Template.Spec.Domain.CPU.Sockets++
-					newVMBytes, err := json.Marshal(&vm)
-					Expect(err).ToNot(HaveOccurred())
-
-					ar := &admissionv1.AdmissionReview{
-						Request: &admissionv1.AdmissionRequest{
-							Resource: webhooks.VirtualMachineGroupVersionResource,
-							Object: runtime.RawExtension{
-								Raw: newVMBytes,
-							},
-							OldObject: runtime.RawExtension{
-								Raw: oldVMBytes,
-							},
-							Operation: admissionv1.Update,
-						},
-					}
-
-					virtClient.EXPECT().VirtualMachineInstance(gomock.Any()).Return(mockVMIClient)
-					mockVMIClient.EXPECT().Get(context.Background(), vmi.Name, gomock.Any()).Return(vmi, nil)
-					response := vmsAdmitter.Admit(ar)
-					Expect(response.Allowed).To(BeFalse())
-					Expect(response.Result.Details.Causes[0].Field).To(Equal("spec.template.spec.domain.cpu.sockets"))
-					Expect(response.Result.Details.Causes[0].Message).To(ContainSubstring("cannot update while VMI migration is in progress"))
-				})
-				It("should reject updating CPU Sockets while VMIMigration exist ", func() {
-					vmi := api.NewMinimalVMI("testvmi")
-
-					inFlightMigration := v1.VirtualMachineInstanceMigration{
-						ObjectMeta: metav1.ObjectMeta{
-							Namespace: vmi.Namespace,
-						},
-						Spec: v1.VirtualMachineInstanceMigrationSpec{
-							VMIName: vmi.Name,
-						},
-					}
-					vm.ObjectMeta = metav1.ObjectMeta{
-						Name:      vmi.Name,
-						Namespace: vmi.Namespace,
-					}
-					vm.Spec.Template.Spec.Domain.CPU = &v1.CPU{
-						Cores:   2,
-						Sockets: 1,
-					}
-					oldVMBytes, err := json.Marshal(&vm)
-					Expect(err).ToNot(HaveOccurred())
-
-					vm.Spec.Template.Spec.Domain.CPU.Sockets++
-					newVMBytes, err := json.Marshal(&vm)
-					Expect(err).ToNot(HaveOccurred())
-
-					ar := &admissionv1.AdmissionReview{
-						Request: &admissionv1.AdmissionRequest{
-							Resource: webhooks.VirtualMachineGroupVersionResource,
-							Object: runtime.RawExtension{
-								Raw: newVMBytes,
-							},
-							OldObject: runtime.RawExtension{
-								Raw: oldVMBytes,
-							},
-							Operation: admissionv1.Update,
-						},
-					}
-					virtClient.EXPECT().VirtualMachineInstance(gomock.Any()).Return(mockVMIClient)
-					mockVMIClient.EXPECT().Get(context.Background(), inFlightMigration.Spec.VMIName, gomock.Any()).Return(vmi, nil)
-					virtClient.EXPECT().VirtualMachineInstanceMigration(gomock.Any()).Return(migrationInterface)
-					migrationInterface.EXPECT().List(gomock.Any()).Return(kubecli.NewMigrationList(inFlightMigration), nil).AnyTimes()
-
-					response := vmsAdmitter.Admit(ar)
-					Expect(response.Allowed).To(BeFalse())
-					Expect(response.Result.Details.Causes[0].Field).To(Equal("spec.template.spec.domain.cpu.sockets"))
-					Expect(response.Result.Details.Causes[0].Message).To(ContainSubstring("cannot update while VMI migration is in progress: in-flight migration detected"))
-				})
-			})
-			When("VM is running", func() {
-				BeforeEach(func() {
-					vm.Status = v1.VirtualMachineStatus{
-						Ready: true,
-					}
-				})
-
-				It("should reject updating of VM live update features", func() {
-					oldVMBytes, err := json.Marshal(&vm)
-					Expect(err).ToNot(HaveOccurred())
-
-					vm.Spec.LiveUpdateFeatures.CPU = &v1.LiveUpdateCPU{}
-					newVMBytes, err := json.Marshal(&vm)
-					Expect(err).ToNot(HaveOccurred())
-
-					ar := &admissionv1.AdmissionReview{
-						Request: &admissionv1.AdmissionRequest{
-							Resource: webhooks.VirtualMachineGroupVersionResource,
-							Object: runtime.RawExtension{
-								Raw: newVMBytes,
-							},
-							OldObject: runtime.RawExtension{
-								Raw: oldVMBytes,
-							},
-							Operation: admissionv1.Update,
-						},
-					}
-
-					response := vmsAdmitter.Admit(ar)
-					Expect(response.Allowed).To(BeFalse())
-					Expect(response.Result.Details.Causes[0].Field).To(Equal("spec"))
-					Expect(response.Result.Details.Causes[0].Message).To(ContainSubstring("Cannot update VM live features while VM is running"))
-				})
-
-				It("should reject updating CPU cores while CPU update feature is enabled ", func() {
-					vm.Spec.Template.Spec.Domain.CPU = &v1.CPU{
-						Cores: 8,
-					}
-					oldVMBytes, err := json.Marshal(&vm)
-					Expect(err).ToNot(HaveOccurred())
-
-					vm.Spec.Template.Spec.Domain.CPU.Cores = 16
-					newVMBytes, err := json.Marshal(&vm)
-					Expect(err).ToNot(HaveOccurred())
-
-					ar := &admissionv1.AdmissionReview{
-						Request: &admissionv1.AdmissionRequest{
-							Resource: webhooks.VirtualMachineGroupVersionResource,
-							Object: runtime.RawExtension{
-								Raw: newVMBytes,
-							},
-							OldObject: runtime.RawExtension{
-								Raw: oldVMBytes,
-							},
-							Operation: admissionv1.Update,
-						},
-					}
-
-					response := vmsAdmitter.Admit(ar)
-					Expect(response.Allowed).To(BeFalse())
-					Expect(response.Result.Details.Causes[0].Field).To(Equal("spec.template.spec.domain.cpu.cores"))
-					Expect(response.Result.Details.Causes[0].Message).To(ContainSubstring("Cannot update CPU cores while live update features configured"))
-				})
-
-				It("should reject updating CPU threads while CPU update feature is enabled", func() {
-					vm.Spec.Template.Spec.Domain.CPU = &v1.CPU{
-						Threads: 8,
-					}
-					oldVMBytes, err := json.Marshal(&vm)
-					Expect(err).ToNot(HaveOccurred())
-
-					vm.Spec.Template.Spec.Domain.CPU.Threads = 16
-					newVMBytes, err := json.Marshal(&vm)
-					Expect(err).ToNot(HaveOccurred())
-
-					ar := &admissionv1.AdmissionReview{
-						Request: &admissionv1.AdmissionRequest{
-							Resource: webhooks.VirtualMachineGroupVersionResource,
-							Object: runtime.RawExtension{
-								Raw: newVMBytes,
-							},
-							OldObject: runtime.RawExtension{
-								Raw: oldVMBytes,
-							},
-							Operation: admissionv1.Update,
-						},
-					}
-
-					response := vmsAdmitter.Admit(ar)
-					Expect(response.Allowed).To(BeFalse())
-					Expect(response.Result.Details.Causes[0].Field).To(Equal("spec.template.spec.domain.cpu.threads"))
-					Expect(response.Result.Details.Causes[0].Message).To(ContainSubstring("Cannot update CPU threads while live update features configured"))
-				})
 			})
 		})
 
@@ -2103,11 +1903,9 @@ var _ = Describe("Validating VM Admitter", func() {
 				guest := resource.MustParse("64Mi")
 				maxGuest = resource.MustParse("128Mi")
 
-				vm.Spec.LiveUpdateFeatures.Memory = &v1.LiveUpdateMemory{
-					MaxGuest: &maxGuest,
-				}
 				vm.Spec.Template.Spec.Domain.Memory = &v1.Memory{
-					Guest: &guest,
+					Guest:    &guest,
+					MaxGuest: &maxGuest,
 				}
 				vm.Spec.Template.Spec.Architecture = rt.GOARCH
 				vm.Spec.Template.Spec.Domain.Resources.Limits = nil
@@ -2122,21 +1920,6 @@ var _ = Describe("Validating VM Admitter", func() {
 				Expect(response.Allowed).To(BeFalse())
 				Expect(response.Result.Details.Causes).To(ContainElement(cause))
 			},
-				Entry("maxGuest is set in VM template", func(vm *v1.VirtualMachine) {
-					vm.Spec.Template.Spec.Domain.Memory.MaxGuest = &maxGuest
-				}, metav1.StatusCause{
-					Type:    metav1.CauseTypeFieldValueNotSupported,
-					Field:   "spec.template.spec.domain.memory.maxGuest",
-					Message: "Memory maxGuest cannot be set directy in VM template",
-				}),
-				Entry("resource limits are configured", func(vm *v1.VirtualMachine) {
-					vm.Spec.Template.Spec.Domain.Resources.Limits = make(k8sv1.ResourceList)
-					vm.Spec.Template.Spec.Domain.Resources.Limits[k8sv1.ResourceMemory] = resource.MustParse("128Mi")
-				}, metav1.StatusCause{
-					Type:    metav1.CauseTypeFieldValueInvalid,
-					Field:   "spec.liveUpdateFeatures",
-					Message: "Configuration of Memory limits is not allowed when Memory live update is enabled",
-				}),
 				Entry("hugepages is configured", func(vm *v1.VirtualMachine) {
 					vm.Spec.Template.Spec.Domain.Memory.Hugepages = &v1.Hugepages{
 						PageSize: "2Mi",
@@ -2213,10 +1996,10 @@ var _ = Describe("Validating VM Admitter", func() {
 				}),
 				Entry("maxGuest is not properly aligned", func(vm *v1.VirtualMachine) {
 					unAlignedMemory := resource.MustParse("333Mi")
-					vm.Spec.LiveUpdateFeatures.Memory.MaxGuest = &unAlignedMemory
+					vm.Spec.Template.Spec.Domain.Memory.MaxGuest = &unAlignedMemory
 				}, metav1.StatusCause{
 					Type:    metav1.CauseTypeFieldValueInvalid,
-					Field:   "spec.liveUpdateFeatures.MaxGuest",
+					Field:   "spec.template.spec.domain.memory.maxGuest",
 					Message: fmt.Sprintf("MaxGuest must be %s aligned", resource.NewQuantity(converter.MemoryHotplugBlockAlignmentBytes, resource.BinarySI)),
 				}),
 				Entry("guest memory is not properly aligned", func(vm *v1.VirtualMachine) {
@@ -2236,49 +2019,31 @@ var _ = Describe("Validating VM Admitter", func() {
 					Message: "Memory hotplug is only available for x86_64 VMs",
 				}),
 			)
-
-			DescribeTable("should reject VM update if", func(vmSetup func(*v1.VirtualMachine, *v1.VirtualMachineInstance), cause metav1.StatusCause) {
-				newVm := vm.DeepCopy()
-
-				guestAtBoot := vm.Spec.Template.Spec.Domain.Memory.Guest.DeepCopy()
-				vmi := api.NewMinimalVMI(vm.Name)
-				vmi.Status.Memory = &v1.MemoryStatus{
-					GuestAtBoot: &guestAtBoot,
-				}
-
-				vmSetup(newVm, vmi)
-
-				virtClient.EXPECT().VirtualMachineInstance(gomock.Any()).Return(mockVMIClient)
-				mockVMIClient.EXPECT().Get(context.Background(), gomock.Any(), gomock.Any()).Return(vmi, nil)
-
-				response := vmsAdmitter.validateVMUpdate(vm, newVm)
-				Expect(response).ToNot(BeNil())
-				Expect(response).To(ContainElement(cause))
-			},
-				Entry("another memory change is in progress", func(vm *v1.VirtualMachine, vmi *v1.VirtualMachineInstance) {
-					newGuest := resource.MustParse("128Mi")
-					vm.Spec.Template.Spec.Domain.Memory.Guest = &newGuest
-
-					vmi.Status.Conditions = append(vmi.Status.Conditions, v1.VirtualMachineInstanceCondition{
-						Type:   v1.VirtualMachineInstanceMemoryChange,
-						Status: k8sv1.ConditionTrue,
-					})
-				}, metav1.StatusCause{
-					Type:    metav1.CauseTypeFieldValueNotSupported,
-					Field:   "spec.template.spec.domain.memory.guest",
-					Message: "cannot update memory while another memory change is in progress",
-				}),
-				Entry("trying to set less memory than what the guest booted with", func(vm *v1.VirtualMachine, vmi *v1.VirtualMachineInstance) {
-					newGuest := resource.MustParse("32Mi")
-					vm.Spec.Template.Spec.Domain.Memory.Guest = &newGuest
-				}, metav1.StatusCause{
-					Type:    metav1.CauseTypeFieldValueNotSupported,
-					Field:   "spec.template.spec.domain.memory.guest",
-					Message: "cannot set less memory than what the guest booted with",
-				}),
-			)
 		})
 	})
+
+	It("should raise a warning when Deprecated API is used", func() {
+		enableFeatureGate(deprecation.PasstGate)
+		vmi := api.NewMinimalVMI("testvmi")
+		vmi.Spec.Domain.Devices.Interfaces = []v1.Interface{
+			{Name: "default", InterfaceBindingMethod: v1.InterfaceBindingMethod{Passt: &v1.InterfacePasst{}}}}
+		vmi.Spec.Networks = []v1.Network{
+			{Name: "default", NetworkSource: v1.NetworkSource{Pod: &v1.PodNetwork{}}}}
+
+		vm := &v1.VirtualMachine{
+			Spec: v1.VirtualMachineSpec{
+				Running: &notRunning,
+				Template: &v1.VirtualMachineInstanceTemplateSpec{
+					Spec: vmi.Spec,
+				},
+			},
+		}
+
+		resp := admitVm(vmsAdmitter, vm)
+		Expect(resp.Allowed).To(BeTrue())
+		Expect(resp.Result).To(BeNil())
+		Expect(resp.Warnings).To(HaveLen(1))
+	})
 })
 
 func admitVm(admitter *VMsAdmitter, vm *v1.VirtualMachine) *admissionv1.AdmissionResponse {
