@@ -11,13 +11,14 @@ import (
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/rand"
-	"k8s.io/utils/pointer"
 
 	v1 "kubevirt.io/api/core/v1"
 
 	cmdv1 "kubevirt.io/kubevirt/pkg/handler-launcher-com/cmd/v1"
 	"kubevirt.io/kubevirt/pkg/testutils"
 	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
+
+	"kubevirt.io/kubevirt/pkg/pointer"
 )
 
 var _ = Describe("test configuration", func() {
@@ -162,31 +163,35 @@ var _ = Describe("test configuration", func() {
 		Entry("when ppc64le unset, GetMachineType should return the default with ppc64le", "ppc64le", "", "", "", virtconfig.DefaultPPC64LEMachineType),
 	)
 
-	Context("when deprecated machineType is set", func() {
-		It("it should have higher priority than the architectureConfiguration", func() {
-			const machineType = "quantum-qc35"
-			const cpuArch = "amd64"
+	It("architectureConfiguration fields should not have higher priority when deprecated options are set", func() {
+		const machineType = "quantum-qc35"
+		const ovmfPath = "/usr/share/something"
+		const cpuArch = "amd64"
+		emulatedMachines := []string{"quantum-*", "old-something-*"}
 
-			clusterConfig, _, _ := testutils.NewFakeClusterConfigUsingKVWithCPUArch(&v1.KubeVirt{
-				ObjectMeta: metav1.ObjectMeta{
-					Name:      "kubevirt",
-					Namespace: "kubevirt",
-				},
-				Spec: v1.KubeVirtSpec{
-					Configuration: v1.KubeVirtConfiguration{
-						MachineType: machineType,
-						ArchitectureConfiguration: &v1.ArchConfiguration{
-							Amd64: &v1.ArchSpecificConfiguration{MachineType: virtconfig.DefaultAMD64MachineType},
-						},
+		clusterConfig, _, _ := testutils.NewFakeClusterConfigUsingKVWithCPUArch(&v1.KubeVirt{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      "kubevirt",
+				Namespace: "kubevirt",
+			},
+			Spec: v1.KubeVirtSpec{
+				Configuration: v1.KubeVirtConfiguration{
+					MachineType:      machineType,
+					EmulatedMachines: emulatedMachines,
+					OVMFPath:         ovmfPath,
+					ArchitectureConfiguration: &v1.ArchConfiguration{
+						Amd64: &v1.ArchSpecificConfiguration{MachineType: virtconfig.DefaultAMD64MachineType},
 					},
 				},
-				Status: v1.KubeVirtStatus{
-					Phase: "Deployed",
-				},
-			}, cpuArch)
+			},
+			Status: v1.KubeVirtStatus{
+				Phase: "Deployed",
+			},
+		}, cpuArch)
 
-			Expect(clusterConfig.GetMachineType(cpuArch)).To(Equal(machineType))
-		})
+		Expect(clusterConfig.GetMachineType(cpuArch)).To(Equal(machineType))
+		Expect(clusterConfig.GetEmulatedMachines(cpuArch)).To(Equal(emulatedMachines))
+		Expect(clusterConfig.GetOVMFPath(cpuArch)).To(Equal(ovmfPath))
 	})
 
 	DescribeTable(" when cpuModel", func(value string, result string) {
@@ -298,6 +303,40 @@ var _ = Describe("test configuration", func() {
 		),
 	)
 
+	DescribeTable("when vmRolloutStrategy", func(vmRolloutStrategy *v1.VMRolloutStrategy, featureGates []string, expected bool) {
+		clusterConfig, _, _ := testutils.NewFakeClusterConfigUsingKV(&v1.KubeVirt{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      "kubevirt",
+				Namespace: "kubevirt",
+			},
+			Spec: v1.KubeVirtSpec{
+				Configuration: v1.KubeVirtConfiguration{
+					DeveloperConfiguration: &v1.DeveloperConfiguration{
+						FeatureGates: featureGates,
+					},
+					VMRolloutStrategy: vmRolloutStrategy,
+				},
+			},
+			Status: v1.KubeVirtStatus{
+				Phase: "Deployed",
+			},
+		})
+		Expect(clusterConfig.IsVMRolloutStrategyLiveUpdate()).To(BeEquivalentTo(expected))
+	},
+		Entry("is nil, VMLiveUpdateFeaturesEnabled should return false",
+			nil, []string{virtconfig.VMLiveUpdateFeaturesGate}, false,
+		),
+		Entry("is Stage, VMLiveUpdateFeaturesEnabled should return false",
+			pointer.P(v1.VMRolloutStrategyStage), []string{virtconfig.VMLiveUpdateFeaturesGate}, false,
+		),
+		Entry("is LiveUpdate but the feature gate is not set, VMLiveUpdateFeaturesEnabled should return false",
+			pointer.P(v1.VMRolloutStrategyLiveUpdate), []string{}, false,
+		),
+		Entry("is LiveUpdate, VMLiveUpdateFeaturesEnabled should return true",
+			pointer.P(v1.VMRolloutStrategyLiveUpdate), []string{virtconfig.VMLiveUpdateFeaturesGate}, true,
+		),
+	)
+
 	DescribeTable(" when maxHotplugRatio", func(value int, expected int) {
 		clusterConfig, _, _ := testutils.NewFakeClusterConfigUsingKVConfig(&v1.KubeVirtConfiguration{
 			LiveUpdateConfiguration: &v1.LiveUpdateConfiguration{
@@ -675,8 +714,8 @@ var _ = Describe("test configuration", func() {
 			v1.KubeVirtConfiguration{
 				NetworkConfiguration: &v1.NetworkConfiguration{
 					NetworkInterface:                  "test",
-					PermitSlirpInterface:              pointer.BoolPtr(true),
-					PermitBridgeInterfaceOnPodNetwork: pointer.BoolPtr(false),
+					PermitSlirpInterface:              pointer.P(true),
+					PermitBridgeInterfaceOnPodNetwork: pointer.P(false),
 				},
 			},
 			func(c *v1.KubeVirtConfiguration) interface{} {
@@ -687,8 +726,8 @@ var _ = Describe("test configuration", func() {
 			v1.KubeVirtConfiguration{
 				NetworkConfiguration: &v1.NetworkConfiguration{
 					NetworkInterface:                  string(v1.SlirpInterface),
-					PermitSlirpInterface:              pointer.BoolPtr(true),
-					PermitBridgeInterfaceOnPodNetwork: pointer.BoolPtr(false),
+					PermitSlirpInterface:              pointer.P(true),
+					PermitBridgeInterfaceOnPodNetwork: pointer.P(false),
 				},
 			},
 			func(c *v1.KubeVirtConfiguration) interface{} {
@@ -698,8 +737,8 @@ var _ = Describe("test configuration", func() {
 		Entry("when networkConfiguration set with empty NetworkInterface, should use the default",
 			v1.KubeVirtConfiguration{
 				NetworkConfiguration: &v1.NetworkConfiguration{
-					PermitSlirpInterface:              pointer.BoolPtr(true),
-					PermitBridgeInterfaceOnPodNetwork: pointer.BoolPtr(false),
+					PermitSlirpInterface:              pointer.P(true),
+					PermitBridgeInterfaceOnPodNetwork: pointer.P(false),
 				},
 			},
 			func(c *v1.KubeVirtConfiguration) interface{} {
@@ -725,7 +764,7 @@ var _ = Describe("test configuration", func() {
 			[]string{virtconfig.ClusterProfiler}, true),
 	)
 
-	Context("deprecated feature gates should always be considered as enabled", func() {
+	Context("GAed feature gates should be considered as enabled by default", func() {
 		var clusterConfig *virtconfig.ClusterConfig
 
 		BeforeEach(func() {
