@@ -21,6 +21,7 @@ package watch
 
 import (
 	"context"
+	"crypto/tls"
 	golog "log"
 	"net/http"
 	"os"
@@ -34,9 +35,6 @@ import (
 	containerdisk "kubevirt.io/kubevirt/pkg/container-disk"
 	kvtls "kubevirt.io/kubevirt/pkg/util/tls"
 
-	"kubevirt.io/kubevirt/pkg/monitoring/migration"
-	"kubevirt.io/kubevirt/pkg/monitoring/migrationstats"
-
 	clonev1alpha1 "kubevirt.io/api/clone/v1alpha1"
 
 	"kubevirt.io/kubevirt/pkg/virt-controller/watch/clone"
@@ -76,10 +74,7 @@ import (
 	"kubevirt.io/kubevirt/pkg/controller"
 	clusterutil "kubevirt.io/kubevirt/pkg/util/cluster"
 
-	"kubevirt.io/kubevirt/pkg/monitoring/perfscale"
-	"kubevirt.io/kubevirt/pkg/monitoring/virt-controller/metrics"
-	vmiprom "kubevirt.io/kubevirt/pkg/monitoring/vmistats" // import for prometheus metrics
-	vmprom "kubevirt.io/kubevirt/pkg/monitoring/vmstats"
+	metrics "kubevirt.io/kubevirt/pkg/monitoring/metrics/virt-controller"
 	"kubevirt.io/kubevirt/pkg/service"
 	"kubevirt.io/kubevirt/pkg/storage/export/export"
 	"kubevirt.io/kubevirt/pkg/storage/snapshot"
@@ -103,6 +98,8 @@ const (
 	exporterImage       = "virt-exportserver"
 	launcherQemuTimeout = 240
 
+	migrationControllerRestTimeout = 30 * time.Second
+
 	imagePullSecret = ""
 
 	virtShareDir = "/var/run/kubevirt"
@@ -266,8 +263,6 @@ func init() {
 	utilruntime.Must(exportv1.AddToScheme(scheme.Scheme))
 	utilruntime.Must(poolv1.AddToScheme(scheme.Scheme))
 	utilruntime.Must(clonev1alpha1.AddToScheme(scheme.Scheme))
-
-	metrics.SetupMetrics()
 }
 
 func Execute() {
@@ -422,6 +417,19 @@ func Execute() {
 
 	app.onOpenshift = onOpenShift
 
+	if err := metrics.SetupMetrics(
+		app.vmInformer,
+		app.vmiInformer,
+		app.clusterInstancetypeInformer,
+		app.instancetypeInformer,
+		app.clusterPreferenceInformer,
+		app.preferenceInformer,
+		app.migrationInformer,
+		app.clusterConfig,
+	); err != nil {
+		golog.Fatal(err)
+	}
+
 	app.initCommon()
 	app.initReplicaSet()
 	app.initPool()
@@ -487,6 +495,9 @@ func (vca *VirtControllerApp) Run() {
 			Addr:      vca.Address(),
 			Handler:   http.DefaultServeMux,
 			TLSConfig: promTLSConfig,
+			// Disable HTTP/2
+			// See CVE-2023-44487
+			TLSNextProto: map[string]func(*http.Server, *tls.Conn, http.Handler){},
 		}
 		if err := server.ListenAndServeTLS("", ""); err != nil {
 			golog.Fatal(err)
@@ -514,20 +525,19 @@ func (vca *VirtControllerApp) onStartedLeading() func(ctx context.Context) {
 			vca.vmControllerThreads, vca.migrationControllerThreads, vca.evacuationControllerThreads,
 			vca.disruptionBudgetControllerThreads)
 
-		vmiprom.SetupVMICollector(
-			vca.vmiInformer,
-			vca.clusterInstancetypeInformer, vca.instancetypeInformer,
-			vca.clusterPreferenceInformer, vca.preferenceInformer,
-			vca.clusterConfig,
-		)
-		vmprom.SetupVMCollector(vca.vmInformer)
-		perfscale.RegisterPerfScaleMetrics(vca.vmiInformer)
+		if err := metrics.AddVMIPhaseTransitionHandlers(vca.vmiInformer); err != nil {
+			golog.Fatalf("failed to add vmi phase transition handler: %v", err)
+		}
+
 		if vca.migrationInformer == nil {
 			vca.migrationInformer = vca.informerFactory.VirtualMachineInstanceMigration()
+			metrics.UpdateVMIMigrationInformer(vca.migrationInformer)
 		}
 		golog.Printf("\nvca.migrationInformer :%v\n", vca.migrationInformer)
-		migration.RegisterMigrationMetrics(vca.migrationInformer)
-		migrationstats.SetupMigrationsCollector(vca.migrationInformer)
+
+		if err := metrics.CreateVMIMigrationHandler(vca.migrationInformer); err != nil {
+			golog.Fatalf("failed to add vmi phase transition time handler: %v", err)
+		}
 
 		go vca.evacuationController.Run(vca.evacuationControllerThreads, stop)
 		go vca.disruptionBudgetController.Run(vca.disruptionBudgetControllerThreads, stop)
@@ -613,6 +623,7 @@ func (vca *VirtControllerApp) initCommon() {
 		vca.vmInformer,
 		vca.kvPodInformer,
 		vca.persistentVolumeClaimInformer,
+		vca.storageClassInformer,
 		vca.vmiRecorder,
 		vca.clientSet,
 		vca.dataVolumeInformer,
@@ -630,6 +641,11 @@ func (vca *VirtControllerApp) initCommon() {
 	if err != nil {
 		panic(err)
 	}
+	// Adding a timeout to the clientSet of the migration controller, to avoid potential deadlocks
+	clientSet, err := vca.clientSet.SetRestTimeout(migrationControllerRestTimeout)
+	if err != nil {
+		panic(err)
+	}
 	vca.migrationController, err = NewMigrationController(
 		vca.templateService,
 		vca.vmiInformer,
@@ -641,7 +657,7 @@ func (vca *VirtControllerApp) initCommon() {
 		vca.migrationPolicyInformer,
 		vca.resourceQuotaInformer,
 		vca.vmiRecorder,
-		vca.clientSet,
+		clientSet,
 		vca.clusterConfig,
 	)
 	if err != nil {
@@ -839,7 +855,7 @@ func (vca *VirtControllerApp) initCloneController() {
 	var err error
 	recorder := vca.newRecorder(k8sv1.NamespaceAll, "clone-controller")
 	vca.vmCloneController, err = clone.NewVmCloneController(
-		vca.clientSet, vca.vmCloneInformer, vca.vmSnapshotInformer, vca.vmRestoreInformer, vca.vmInformer, vca.vmSnapshotContentInformer, recorder,
+		vca.clientSet, vca.vmCloneInformer, vca.vmSnapshotInformer, vca.vmRestoreInformer, vca.vmInformer, vca.vmSnapshotContentInformer, vca.persistentVolumeClaimInformer, recorder,
 	)
 	if err != nil {
 		panic(err)
