@@ -63,14 +63,21 @@ type syncInfoType struct {
 	restoreReady    bool
 	targetVMName    string
 	targetVMCreated bool
+	pvcBound        bool
 
 	isCloneFailing bool
 	failEvent      Event
 	failReason     string
+}
 
-	// This flag is true when we need to reenqueue and return syncInfo from sync() for a reason not specified above.
-	needToReenqueue bool
-	logger          *log.FilteredLogger
+// vmCloneInfo stores the current vmclone information
+type vmCloneInfo struct {
+	vmClone      *clonev1alpha1.VirtualMachineClone
+	sourceType   cloneSourceType
+	snapshot     *snapshotv1alpha1.VirtualMachineSnapshot
+	snapshotName string
+	sourceVm     *k6tv1.VirtualMachine
+	restore      *snapshotv1alpha1.VirtualMachineRestore
 }
 
 func (ctrl *VMCloneController) execute(key string) error {
@@ -89,6 +96,22 @@ func (ctrl *VMCloneController) execute(key string) error {
 		return nil
 	}
 
+	if vmClone.Status.Phase == clonev1alpha1.Succeeded {
+		_, vmExists, err := ctrl.vmInformer.GetStore().GetByKey(fmt.Sprintf("%s/%s", vmClone.Namespace, *vmClone.Status.TargetName))
+		if err != nil {
+			return err
+		}
+
+		if !vmExists {
+			if vmClone.DeletionTimestamp == nil {
+				logger.V(3).Infof("Deleting vm clone for deleted vm %s/%s", vmClone.Namespace, *vmClone.Status.TargetName)
+				return ctrl.client.VirtualMachineClone(vmClone.Namespace).Delete(context.Background(), vmClone.Name, v1.DeleteOptions{})
+			}
+			// nothing to process for a vm clone that's being deleted
+			return nil
+		}
+	}
+
 	syncInfo, err := ctrl.sync(vmClone)
 	if err != nil {
 		return fmt.Errorf("sync error: %v", err)
@@ -107,154 +130,99 @@ func (ctrl *VMCloneController) execute(key string) error {
 }
 
 func (ctrl *VMCloneController) sync(vmClone *clonev1alpha1.VirtualMachineClone) (syncInfoType, error) {
-	var syncInfo syncInfoType
+	cloneInfo, err := ctrl.retrieveCloneInfo(vmClone)
+	if err != nil {
+		return syncInfoType{}, err
+	}
+
+	if ctrl.getTargetType(cloneInfo.vmClone) == targetTypeVM {
+		return ctrl.syncTargetVM(cloneInfo), nil
+	}
+	return syncInfoType{err: fmt.Errorf("target type is unknown: %s", ctrl.getTargetType(cloneInfo.vmClone))}, nil
+}
+
+// retrieveCloneInfo initializes all the snapshot and restore information that can be populated from the vm clone resource
+func (ctrl *VMCloneController) retrieveCloneInfo(vmClone *clonev1alpha1.VirtualMachineClone) (*vmCloneInfo, error) {
 	sourceInfo := vmClone.Spec.Source
+	cloneInfo := vmCloneInfo{
+		vmClone:    vmClone,
+		sourceType: cloneSourceType(sourceInfo.Kind),
+	}
 
 	switch cloneSourceType(sourceInfo.Kind) {
 	case sourceTypeVM:
 		sourceVMObj, err := ctrl.getSource(vmClone, sourceInfo.Name, vmClone.Namespace, string(sourceTypeVM), ctrl.vmInformer.GetStore())
 		if err != nil {
-			return syncInfo, err
+			return nil, err
 		}
 
 		sourceVM := sourceVMObj.(*k6tv1.VirtualMachine)
-
-		syncInfo = ctrl.syncSourceVM(sourceVM, vmClone)
-		return syncInfo, nil
+		cloneInfo.sourceVm = sourceVM
 
 	case sourceTypeSnapshot:
 		sourceSnapshotObj, err := ctrl.getSource(vmClone, sourceInfo.Name, vmClone.Namespace, string(sourceTypeSnapshot), ctrl.snapshotInformer.GetStore())
 		if err != nil {
-			return syncInfo, err
+			return nil, err
 		}
 
 		sourceSnapshot := sourceSnapshotObj.(*snapshotv1alpha1.VirtualMachineSnapshot)
-
-		syncInfo = ctrl.syncSourceSnapshot(sourceSnapshot, vmClone)
-		return syncInfo, nil
+		cloneInfo.snapshot = sourceSnapshot
+		cloneInfo.snapshotName = sourceSnapshot.Name
 
 	default:
-		return syncInfo, fmt.Errorf("clone %s is defined with an unknown source type %s", vmClone.Name, sourceInfo.Kind)
+		return nil, fmt.Errorf("clone %s is defined with an unknown source type %s", vmClone.Name, sourceInfo.Kind)
 	}
+
+	if cloneInfo.snapshotName == "" && vmClone.Status.SnapshotName != nil {
+		cloneInfo.snapshotName = *vmClone.Status.SnapshotName
+	}
+
+	return &cloneInfo, nil
 }
 
-func (ctrl *VMCloneController) syncSourceVM(source *k6tv1.VirtualMachine, vmClone *clonev1alpha1.VirtualMachineClone) syncInfoType {
-	targetType := ctrl.getTargetType(vmClone)
-
-	switch targetType {
-	case targetTypeVM:
-		return ctrl.syncSourceVMTargetVM(source, vmClone)
-
-	default:
-		return syncInfoType{err: fmt.Errorf("target type is unknown: %s", targetType)}
-	}
-}
-
-func (ctrl *VMCloneController) syncSourceSnapshot(source *snapshotv1alpha1.VirtualMachineSnapshot, vmClone *clonev1alpha1.VirtualMachineClone) syncInfoType {
-	targetType := ctrl.getTargetType(vmClone)
-
-	switch targetType {
-	case targetTypeVM:
-		return ctrl.syncSourceSnapshotTargetVM(source, vmClone)
-
-	default:
-		return syncInfoType{err: fmt.Errorf("target type is unknown: %s", targetType)}
-	}
-}
-
-func (ctrl *VMCloneController) syncSourceVMTargetVM(source *k6tv1.VirtualMachine, vmClone *clonev1alpha1.VirtualMachineClone) syncInfoType {
-	syncInfo := syncInfoType{logger: log.Log.Object(vmClone)}
-
-	var snapshot *snapshotv1alpha1.VirtualMachineSnapshot
+func (ctrl *VMCloneController) syncTargetVM(vmCloneInfo *vmCloneInfo) syncInfoType {
+	vmClone := vmCloneInfo.vmClone
+	syncInfo := syncInfoType{}
 
 	switch vmClone.Status.Phase {
 	case clonev1alpha1.PhaseUnset, clonev1alpha1.SnapshotInProgress:
 
-		if vmClone.Status.SnapshotName == nil {
-			_, syncInfo = ctrl.createSnapshotFromVm(vmClone, source, syncInfo)
-			return syncInfo
+		if vmCloneInfo.sourceType == sourceTypeVM {
+			if vmClone.Status.SnapshotName == nil {
+				_, syncInfo = ctrl.createSnapshotFromVm(vmClone, vmCloneInfo.sourceVm, syncInfo)
+				return syncInfo
+			}
 		}
 
-		snapshot, syncInfo = ctrl.verifySnapshotReady(vmClone, *vmClone.Status.SnapshotName, source.Namespace, syncInfo)
-		if syncInfo.toReenqueue() || !syncInfo.snapshotReady {
+		vmCloneInfo.snapshot, syncInfo = ctrl.verifySnapshotReady(vmClone, vmCloneInfo.snapshotName, vmCloneInfo.vmClone.Namespace, syncInfo)
+		if syncInfo.isFailingOrError() || !syncInfo.snapshotReady {
 			return syncInfo
 		}
 
 		fallthrough
 
 	case clonev1alpha1.RestoreInProgress:
-
-		if snapshot == nil {
-			snapshot, syncInfo = ctrl.getSnapshot(vmClone, source.Namespace, syncInfo)
-			if syncInfo.toReenqueue() {
+		// Here we have to know the snapshot name
+		if vmCloneInfo.snapshot == nil {
+			vmCloneInfo.snapshot, syncInfo = ctrl.getSnapshot(vmCloneInfo.snapshotName, vmCloneInfo.vmClone.Namespace, syncInfo)
+			if syncInfo.isFailingOrError() {
 				return syncInfo
 			}
 		}
 
 		if vmClone.Status.RestoreName == nil {
-			syncInfo = ctrl.createRestoreFromVm(vmClone, source, snapshot.Name, syncInfo)
-			return syncInfo
-		}
-
-		syncInfo = ctrl.verifyRestoreReady(vmClone, source.Namespace, syncInfo)
-		if syncInfo.toReenqueue() {
-			return syncInfo
-		}
-
-		fallthrough
-
-	case clonev1alpha1.CreatingTargetVM:
-
-		syncInfo = ctrl.verifyVmReady(vmClone, syncInfo)
-		if syncInfo.toReenqueue() {
-			return syncInfo
-		}
-
-		syncInfo = ctrl.cleanupSnapshot(vmClone, syncInfo)
-		if syncInfo.toReenqueue() {
-			return syncInfo
-		}
-
-		syncInfo = ctrl.cleanupRestore(vmClone, syncInfo)
-		if syncInfo.toReenqueue() {
-			return syncInfo
-		}
-
-	default:
-		log.Log.Object(vmClone).Infof("clone %s is in phase %s - nothing to do", vmClone.Name, string(vmClone.Status.Phase))
-	}
-
-	return syncInfo
-}
-
-func (ctrl *VMCloneController) syncSourceSnapshotTargetVM(source *snapshotv1alpha1.VirtualMachineSnapshot, vmClone *clonev1alpha1.VirtualMachineClone) syncInfoType {
-	syncInfo := syncInfoType{logger: log.Log.Object(vmClone)}
-
-	switch vmClone.Status.Phase {
-	case clonev1alpha1.PhaseUnset, clonev1alpha1.SnapshotInProgress:
-
-		syncInfo.snapshotName = source.Name
-		source, syncInfo = ctrl.verifySnapshotReady(vmClone, source.Name, source.Namespace, syncInfo)
-		if syncInfo.toReenqueue() || !syncInfo.snapshotReady {
-			return syncInfo
-		}
-
-		fallthrough
-
-	case clonev1alpha1.RestoreInProgress:
-
-		if vmClone.Status.RestoreName == nil {
-			vm, err := ctrl.getVmFromSnapshot(source)
+			vm, err := ctrl.getVmFromSnapshot(vmCloneInfo.snapshot)
 			if err != nil {
-				return addErrorToSyncInfo(syncInfo, fmt.Errorf("cannot get VM manifest from snapshot: %v", err))
+				syncInfo.setError(fmt.Errorf("cannot get VM manifest from snapshot: %v", err))
+				return syncInfo
 			}
 
-			syncInfo = ctrl.createRestoreFromVm(vmClone, vm, source.Name, syncInfo)
+			syncInfo = ctrl.createRestoreFromVm(vmClone, vm, vmCloneInfo.snapshotName, syncInfo)
 			return syncInfo
 		}
 
-		syncInfo = ctrl.verifyRestoreReady(vmClone, source.Namespace, syncInfo)
-		if syncInfo.toReenqueue() {
+		syncInfo = ctrl.verifyRestoreReady(vmClone, vmCloneInfo.vmClone.Namespace, syncInfo)
+		if syncInfo.isFailingOrError() || !syncInfo.restoreReady {
 			return syncInfo
 		}
 
@@ -263,13 +231,31 @@ func (ctrl *VMCloneController) syncSourceSnapshotTargetVM(source *snapshotv1alph
 	case clonev1alpha1.CreatingTargetVM:
 
 		syncInfo = ctrl.verifyVmReady(vmClone, syncInfo)
-		if syncInfo.toReenqueue() {
+		if syncInfo.isFailingOrError() {
 			return syncInfo
 		}
 
-		syncInfo = ctrl.cleanupRestore(vmClone, syncInfo)
-		if syncInfo.toReenqueue() {
-			return syncInfo
+		fallthrough
+
+	case clonev1alpha1.Succeeded:
+
+		if vmClone.Status.RestoreName != nil {
+			syncInfo = ctrl.verifyPVCBound(vmClone, syncInfo)
+			if syncInfo.isFailingOrError() || !syncInfo.pvcBound {
+				return syncInfo
+			}
+
+			syncInfo = ctrl.cleanupRestore(vmClone, syncInfo)
+			if syncInfo.isFailingOrError() {
+				return syncInfo
+			}
+
+			if vmCloneInfo.sourceType == sourceTypeVM {
+				syncInfo = ctrl.cleanupSnapshot(vmClone, syncInfo)
+				if syncInfo.isFailingOrError() {
+					return syncInfo
+				}
+			}
 		}
 
 	default:
@@ -329,8 +315,6 @@ func (ctrl *VMCloneController) updateStatus(origClone *clonev1alpha1.VirtualMach
 		}
 
 		if syncInfo.targetVMCreated {
-			vmClone.Status.SnapshotName = nil
-			vmClone.Status.RestoreName = nil
 			assignPhase(clonev1alpha1.Succeeded)
 
 		}
@@ -342,6 +326,11 @@ func (ctrl *VMCloneController) updateStatus(origClone *clonev1alpha1.VirtualMach
 		)
 	}
 
+	if syncInfo.pvcBound {
+		vmClone.Status.SnapshotName = nil
+		vmClone.Status.RestoreName = nil
+	}
+
 	if !equality.Semantic.DeepEqual(vmClone.Status, origClone.Status) {
 		if phaseChanged {
 			log.Log.Object(vmClone).Infof("Changing phase to %s", vmClone.Status.Phase)
@@ -357,32 +346,40 @@ func (ctrl *VMCloneController) updateStatus(origClone *clonev1alpha1.VirtualMach
 
 func (ctrl *VMCloneController) createSnapshotFromVm(vmClone *clonev1alpha1.VirtualMachineClone, vm *k6tv1.VirtualMachine, syncInfo syncInfoType) (*snapshotv1alpha1.VirtualMachineSnapshot, syncInfoType) {
 	snapshot := generateSnapshot(vmClone, vm)
-	syncInfo.logger.Infof("creating snapshot %s for clone %s", snapshot.Name, vmClone.Name)
+	log.Log.Object(vmClone).Infof("creating snapshot %s for clone %s", snapshot.Name, vmClone.Name)
 
-	snapshot, syncInfo.err = ctrl.client.VirtualMachineSnapshot(snapshot.Namespace).Create(context.Background(), snapshot, v1.CreateOptions{})
-	if syncInfo.err != nil {
-		return snapshot, addErrorToSyncInfo(syncInfo, fmt.Errorf("failed creating snapshot %s for clone %s: %v", snapshot.Name, vmClone.Name, syncInfo.err))
+	createdSnapshot, err := ctrl.client.VirtualMachineSnapshot(snapshot.Namespace).Create(context.Background(), snapshot, v1.CreateOptions{})
+	if err != nil {
+		if !errors.IsAlreadyExists(err) {
+			syncInfo.setError(fmt.Errorf("failed creating snapshot %s for clone %s: %v", snapshot.Name, vmClone.Name, err))
+			return snapshot, syncInfo
+		}
+		syncInfo.snapshotName = snapshot.Name
+		return snapshot, syncInfo
 	}
 
+	snapshot = createdSnapshot
 	ctrl.logAndRecord(vmClone, SnapshotCreated, fmt.Sprintf("created snapshot %s for clone %s", snapshot.Name, vmClone.Name))
 	syncInfo.snapshotName = snapshot.Name
 
-	syncInfo.logger.V(defaultVerbosityLevel).Infof("snapshot %s was just created, reenqueuing to let snapshot time to finish", snapshot.Name)
+	log.Log.Object(vmClone).V(defaultVerbosityLevel).Infof("snapshot %s was just created, reenqueuing to let snapshot time to finish", snapshot.Name)
 	return snapshot, syncInfo
 }
 
 func (ctrl *VMCloneController) verifySnapshotReady(vmClone *clonev1alpha1.VirtualMachineClone, name, namespace string, syncInfo syncInfoType) (*snapshotv1alpha1.VirtualMachineSnapshot, syncInfoType) {
 	obj, exists, err := ctrl.snapshotInformer.GetStore().GetByKey(getKey(name, namespace))
 	if err != nil {
-		return nil, addErrorToSyncInfo(syncInfo, fmt.Errorf("error getting snapshot %s from cache for clone %s: %v", name, vmClone.Name, err))
+		syncInfo.setError(fmt.Errorf("error getting snapshot %s from cache for clone %s: %v", name, vmClone.Name, err))
+		return nil, syncInfo
 	} else if !exists {
-		return nil, addErrorToSyncInfo(syncInfo, fmt.Errorf("snapshot %s is not created yet for clone %s", name, vmClone.Name))
+		syncInfo.setError(fmt.Errorf("snapshot %s is not created yet for clone %s", name, vmClone.Name))
+		return nil, syncInfo
 	}
 	snapshot := obj.(*snapshotv1alpha1.VirtualMachineSnapshot)
-	syncInfo.logger.Infof("found snapshot %s for clone %s", snapshot.Name, vmClone.Name)
+	log.Log.Object(vmClone).Infof("found snapshot %s for clone %s", snapshot.Name, vmClone.Name)
 
 	if !virtsnapshot.VmSnapshotReady(snapshot) {
-		syncInfo.logger.V(defaultVerbosityLevel).Infof("snapshot %s for clone %s is not ready to use yet", snapshot.Name, vmClone.Name)
+		log.Log.Object(vmClone).V(defaultVerbosityLevel).Infof("snapshot %s for clone %s is not ready to use yet", snapshot.Name, vmClone.Name)
 		return snapshot, syncInfo
 	}
 
@@ -393,18 +390,19 @@ func (ctrl *VMCloneController) verifySnapshotReady(vmClone *clonev1alpha1.Virtua
 }
 
 // This method assumes the snapshot exists. If it doesn't - syncInfo is updated accordingly.
-func (ctrl *VMCloneController) getSnapshot(vmClone *clonev1alpha1.VirtualMachineClone, sourceNamespace string, syncInfo syncInfoType) (*snapshotv1alpha1.VirtualMachineSnapshot, syncInfoType) {
-	obj, exists, err := ctrl.snapshotInformer.GetStore().GetByKey(getKey(*vmClone.Status.SnapshotName, sourceNamespace))
+func (ctrl *VMCloneController) getSnapshot(snapshotName string, sourceNamespace string, syncInfo syncInfoType) (*snapshotv1alpha1.VirtualMachineSnapshot, syncInfoType) {
+	obj, exists, err := ctrl.snapshotInformer.GetStore().GetByKey(getKey(snapshotName, sourceNamespace))
 	if !exists {
 		// At this point the snapshot is already created. If it doesn't exist it means that it's deleted for some
 		// reason and the clone should fail
 		syncInfo.isCloneFailing = true
 		syncInfo.failEvent = SnapshotDeleted
-		syncInfo.failReason = fmt.Sprintf("snapshot %s does not exist anymore", *vmClone.Status.SnapshotName)
+		syncInfo.failReason = fmt.Sprintf("snapshot %s does not exist anymore", snapshotName)
 		return nil, syncInfo
 	}
 	if err != nil {
-		return nil, addErrorToSyncInfo(syncInfo, fmt.Errorf("error getting snapshot %s from cache for clone %s: %v", *vmClone.Status.SnapshotName, vmClone.Name, err))
+		syncInfo.setError(fmt.Errorf("error getting snapshot %s from cache: %v", snapshotName, err))
+		return nil, syncInfo
 	}
 	snapshot := obj.(*snapshotv1alpha1.VirtualMachineSnapshot)
 
@@ -414,34 +412,41 @@ func (ctrl *VMCloneController) getSnapshot(vmClone *clonev1alpha1.VirtualMachine
 func (ctrl *VMCloneController) createRestoreFromVm(vmClone *clonev1alpha1.VirtualMachineClone, vm *k6tv1.VirtualMachine, snapshotName string, syncInfo syncInfoType) syncInfoType {
 	patches := generatePatches(vm, &vmClone.Spec)
 	restore := generateRestore(vmClone.Spec.Target, vm.Name, vmClone.Namespace, vmClone.Name, snapshotName, vmClone.UID, patches)
-	syncInfo.logger.Infof("creating restore %s for clone %s", restore.Name, vmClone.Name)
-
-	restore, syncInfo.err = ctrl.client.VirtualMachineRestore(restore.Namespace).Create(context.Background(), restore, v1.CreateOptions{})
-	if syncInfo.err != nil {
-		return addErrorToSyncInfo(syncInfo, fmt.Errorf("failed creating restore %s for clone %s: %v", restore.Name, vmClone.Name, syncInfo.err))
+	log.Log.Object(vmClone).Infof("creating restore %s for clone %s", restore.Name, vmClone.Name)
+	createdRestore, err := ctrl.client.VirtualMachineRestore(restore.Namespace).Create(context.Background(), restore, v1.CreateOptions{})
+	if err != nil {
+		if !errors.IsAlreadyExists(err) {
+			retErr := fmt.Errorf("failed creating restore %s for clone %s: %v", restore.Name, vmClone.Name, err)
+			ctrl.recorder.Event(vmClone, corev1.EventTypeWarning, string(RestoreCreationFailed), retErr.Error())
+			syncInfo.setError(retErr)
+			return syncInfo
+		}
+		syncInfo.restoreName = restore.Name
+		return syncInfo
 	}
-
+	restore = createdRestore
 	ctrl.logAndRecord(vmClone, RestoreCreated, fmt.Sprintf("created restore %s for clone %s", restore.Name, vmClone.Name))
 	syncInfo.restoreName = restore.Name
 
-	syncInfo.logger.V(defaultVerbosityLevel).Infof("restore %s was just created, reenqueuing to let snapshot time to finish", restore.Name)
+	log.Log.Object(vmClone).V(defaultVerbosityLevel).Infof("restore %s was just created, reenqueuing to let snapshot time to finish", restore.Name)
 	return syncInfo
 }
 
 func (ctrl *VMCloneController) verifyRestoreReady(vmClone *clonev1alpha1.VirtualMachineClone, sourceNamespace string, syncInfo syncInfoType) syncInfoType {
 	obj, exists, err := ctrl.restoreInformer.GetStore().GetByKey(getKey(*vmClone.Status.RestoreName, sourceNamespace))
 	if !exists {
-		return addErrorToSyncInfo(syncInfo, fmt.Errorf("restore %s is not created yet for clone %s", *vmClone.Status.SnapshotName, vmClone.Name))
+		syncInfo.setError(fmt.Errorf("restore %s is not created yet for clone %s", *vmClone.Status.RestoreName, vmClone.Name))
+		return syncInfo
 	} else if err != nil {
-		return addErrorToSyncInfo(syncInfo, fmt.Errorf("error getting snapshot %s from cache for clone %s: %v", *vmClone.Status.SnapshotName, vmClone.Name, err))
+		syncInfo.setError(fmt.Errorf("error getting restore %s from cache for clone %s: %v", *vmClone.Status.RestoreName, vmClone.Name, err))
+		return syncInfo
 	}
 
 	restore := obj.(*snapshotv1alpha1.VirtualMachineRestore)
-	syncInfo.logger.Infof("found target restore %s for clone %s", restore.Name, vmClone.Name)
+	log.Log.Object(vmClone).Infof("found target restore %s for clone %s", restore.Name, vmClone.Name)
 
 	if virtsnapshot.VmRestoreProgressing(restore) {
-		syncInfo.logger.V(defaultVerbosityLevel).Infof("restore %s for clone %s is not ready to use yet", restore.Name, vmClone.Name)
-		syncInfo.needToReenqueue = true
+		log.Log.Object(vmClone).V(defaultVerbosityLevel).Infof("restore %s for clone %s is not ready to use yet", restore.Name, vmClone.Name)
 		return syncInfo
 	}
 
@@ -457,9 +462,11 @@ func (ctrl *VMCloneController) verifyVmReady(vmClone *clonev1alpha1.VirtualMachi
 
 	_, exists, err := ctrl.vmInformer.GetStore().GetByKey(getKey(targetVMInfo.Name, vmClone.Namespace))
 	if !exists {
-		return addErrorToSyncInfo(syncInfo, fmt.Errorf("target VM %s is not created yet for clone %s", targetVMInfo.Name, vmClone.Name))
+		syncInfo.setError(fmt.Errorf("target VM %s is not created yet for clone %s", targetVMInfo.Name, vmClone.Name))
+		return syncInfo
 	} else if err != nil {
-		return addErrorToSyncInfo(syncInfo, fmt.Errorf("error getting VM %s from cache for clone %s: %v", *vmClone.Status.SnapshotName, targetVMInfo.Name, err))
+		syncInfo.setError(fmt.Errorf("error getting VM %s from cache for clone %s: %v", targetVMInfo.Name, vmClone.Name, err))
+		return syncInfo
 	}
 
 	ctrl.logAndRecord(vmClone, TargetVMCreated, fmt.Sprintf("created target VM %s for clone %s", targetVMInfo.Name, vmClone.Name))
@@ -468,10 +475,46 @@ func (ctrl *VMCloneController) verifyVmReady(vmClone *clonev1alpha1.VirtualMachi
 	return syncInfo
 }
 
+func (ctrl *VMCloneController) verifyPVCBound(vmClone *clonev1alpha1.VirtualMachineClone, syncInfo syncInfoType) syncInfoType {
+	obj, exists, err := ctrl.restoreInformer.GetStore().GetByKey(getKey(*vmClone.Status.RestoreName, vmClone.Namespace))
+	if !exists {
+		syncInfo.setError(fmt.Errorf("restore %s is not created yet for clone %s", *vmClone.Status.RestoreName, vmClone.Name))
+		return syncInfo
+	} else if err != nil {
+		syncInfo.setError(fmt.Errorf("error getting restore %s from cache for clone %s: %v", *vmClone.Status.SnapshotName, vmClone.Name, err))
+		return syncInfo
+	}
+
+	restore := obj.(*snapshotv1alpha1.VirtualMachineRestore)
+	for _, volumeRestore := range restore.Status.Restores {
+		obj, exists, err = ctrl.pvcInformer.GetStore().GetByKey(getKey(volumeRestore.PersistentVolumeClaimName, vmClone.Namespace))
+		if !exists {
+			syncInfo.setError(fmt.Errorf("PVC %s is not created yet for clone %s", volumeRestore.PersistentVolumeClaimName, vmClone.Name))
+			return syncInfo
+		} else if err != nil {
+			syncInfo.setError(fmt.Errorf("error getting PVC %s from cache for clone %s: %v", volumeRestore.PersistentVolumeClaimName, vmClone.Name, err))
+			return syncInfo
+		}
+
+		pvc := obj.(*corev1.PersistentVolumeClaim)
+		if pvc.Status.Phase != corev1.ClaimBound {
+			log.Log.Object(vmClone).V(defaultVerbosityLevel).Infof("pvc %s for clone %s is not bound yet", pvc.Name, vmClone.Name)
+			return syncInfo
+		}
+	}
+
+	ctrl.logAndRecord(vmClone, PVCBound, fmt.Sprintf("all PVC for clone %s are bound", vmClone.Name))
+	syncInfo.pvcBound = true
+
+	return syncInfo
+
+}
+
 func (ctrl *VMCloneController) cleanupSnapshot(vmClone *clonev1alpha1.VirtualMachineClone, syncInfo syncInfoType) syncInfoType {
 	err := ctrl.client.VirtualMachineSnapshot(vmClone.Namespace).Delete(context.Background(), *vmClone.Status.SnapshotName, v1.DeleteOptions{})
 	if err != nil && !errors.IsNotFound(err) {
-		return addErrorToSyncInfo(syncInfo, fmt.Errorf("cannot clean up snapshot %s for clone %s", *vmClone.Status.SnapshotName, vmClone.Name))
+		syncInfo.setError(fmt.Errorf("cannot clean up snapshot %s for clone %s", *vmClone.Status.SnapshotName, vmClone.Name))
+		return syncInfo
 	}
 
 	return syncInfo
@@ -480,7 +523,8 @@ func (ctrl *VMCloneController) cleanupSnapshot(vmClone *clonev1alpha1.VirtualMac
 func (ctrl *VMCloneController) cleanupRestore(vmClone *clonev1alpha1.VirtualMachineClone, syncInfo syncInfoType) syncInfoType {
 	err := ctrl.client.VirtualMachineRestore(vmClone.Namespace).Delete(context.Background(), *vmClone.Status.RestoreName, v1.DeleteOptions{})
 	if err != nil && !errors.IsNotFound(err) {
-		return addErrorToSyncInfo(syncInfo, fmt.Errorf("cannot clean up restore %s for clone %s", *vmClone.Status.RestoreName, vmClone.Name))
+		syncInfo.setError(fmt.Errorf("cannot clean up restore %s for clone %s", *vmClone.Status.RestoreName, vmClone.Name))
+		return syncInfo
 	}
 
 	return syncInfo
@@ -545,11 +589,10 @@ func (ctrl *VMCloneController) getVmFromSnapshot(snapshot *snapshotv1alpha1.Virt
 	return vm, nil
 }
 
-func addErrorToSyncInfo(info syncInfoType, err error) syncInfoType {
-	info.err = err
-	return info
+func (s *syncInfoType) setError(err error) {
+	s.err = err
 }
 
-func (s *syncInfoType) toReenqueue() bool {
-	return s.err != nil || s.isCloneFailing || s.needToReenqueue
+func (s *syncInfoType) isFailingOrError() bool {
+	return s.err != nil || s.isCloneFailing
 }
