@@ -22,78 +22,47 @@
 package nodelabeller
 
 import (
-	"path"
 	"strings"
 
-	"github.com/golang/mock/gomock"
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 	k8sv1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
 	kubevirtv1 "kubevirt.io/api/core/v1"
-	"kubevirt.io/client-go/kubecli"
 	"kubevirt.io/client-go/log"
 
 	"kubevirt.io/kubevirt/pkg/testutils"
 	util "kubevirt.io/kubevirt/pkg/virt-handler/node-labeller/util"
 )
 
-var features = []string{"apic", "clflush", "cmov"}
-
-const (
-	x86PenrynXml = "x86_Penryn.xml"
-)
-
-var nlController *NodeLabeller
-
-var _ = BeforeSuite(func() {
-	ctrl := gomock.NewController(GinkgoT())
-	virtClient := kubecli.NewMockKubevirtClient(ctrl)
-
-	kv := &kubevirtv1.KubeVirt{
-		ObjectMeta: metav1.ObjectMeta{
-			Name:      "kubevirt",
-			Namespace: "kubevirt",
-		},
-		Spec: kubevirtv1.KubeVirtSpec{
-			Configuration: kubevirtv1.KubeVirtConfiguration{
-				ObsoleteCPUModels: util.DefaultObsoleteCPUModels,
-				MinCPUModel:       util.DefaultMinCPUModel,
-			},
-		},
-	}
-
-	clusterConfig, _, _ := testutils.NewFakeClusterConfigUsingKV(kv)
-
-	nlController = &NodeLabeller{
-		namespace:               k8sv1.NamespaceDefault,
-		clientset:               virtClient,
-		clusterConfig:           clusterConfig,
-		logger:                  log.DefaultLogger(),
-		volumePath:              "testdata",
-		domCapabilitiesFileName: "virsh_domcapabilities.xml",
-		hostCPUModel:            hostCPUModel{requiredFeatures: make(map[string]bool, 0)},
-	}
-})
-
 var _ = Describe("Node-labeller config", func() {
-	It("should return correct cpu file path", func() {
-		p := getPathCPUFeatures(nlController.volumePath, x86PenrynXml)
-		correctPath := path.Join(nlController.volumePath, "cpu_map", x86PenrynXml)
-		Expect(p).To(Equal(correctPath), "cpu file path is not the same")
-	})
+	var nlController *NodeLabeller
 
-	It("should load cpu features", func() {
-		fileName := x86PenrynXml
-		f, err := nlController.loadFeatures(fileName)
-		Expect(err).ToNot(HaveOccurred())
-		for _, val := range features {
-			if _, ok := f[val]; !ok {
-				Expect(ok).To(BeFalse(), "expect feature")
-			}
+	BeforeEach(func() {
+		kv := &kubevirtv1.KubeVirt{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      "kubevirt",
+				Namespace: "kubevirt",
+			},
+			Spec: kubevirtv1.KubeVirtSpec{
+				Configuration: kubevirtv1.KubeVirtConfiguration{
+					ObsoleteCPUModels: util.DefaultObsoleteCPUModels,
+					MinCPUModel:       util.DefaultMinCPUModel,
+				},
+			},
 		}
 
+		clusterConfig, _, _ := testutils.NewFakeClusterConfigUsingKV(kv)
+
+		nlController = &NodeLabeller{
+			nodeClient:              nil,
+			clusterConfig:           clusterConfig,
+			logger:                  log.DefaultLogger(),
+			volumePath:              "testdata",
+			domCapabilitiesFileName: "virsh_domcapabilities.xml",
+			hostCPUModel:            hostCPUModel{requiredFeatures: make(map[string]bool, 0)},
+		}
 	})
 
 	It("should return correct cpu models, features and tsc freqnency", func() {
@@ -103,16 +72,13 @@ var _ = Describe("Node-labeller config", func() {
 		err = nlController.loadHostSupportedFeatures()
 		Expect(err).ToNot(HaveOccurred())
 
-		err = nlController.loadCPUInfo()
-		Expect(err).ToNot(HaveOccurred())
-
 		err = nlController.loadHostCapabilities()
 		Expect(err).ToNot(HaveOccurred())
 
 		cpuModels := nlController.getSupportedCpuModels(nlController.clusterConfig.GetObsoleteCPUModels())
 		cpuFeatures := nlController.getSupportedCpuFeatures()
 
-		Expect(cpuModels).To(HaveLen(5), "number of models must match")
+		Expect(cpuModels).To(HaveLen(4), "number of models must match")
 
 		Expect(cpuFeatures).To(HaveLen(4), "number of features must match")
 		counter, err := nlController.capabilities.GetTSCCounter()
@@ -127,8 +93,7 @@ var _ = Describe("Node-labeller config", func() {
 		err := nlController.loadDomCapabilities()
 		Expect(err).ToNot(HaveOccurred())
 
-		err = nlController.loadCPUInfo()
-		Expect(err).ToNot(HaveOccurred())
+		Expect(nlController.loadHostSupportedFeatures()).To(Succeed())
 
 		cpuModels := nlController.getSupportedCpuModels(nlController.clusterConfig.GetObsoleteCPUModels())
 		cpuFeatures := nlController.getSupportedCpuFeatures()
