@@ -35,10 +35,10 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/wait"
+	k8scli "k8s.io/client-go/kubernetes/typed/core/v1"
 	"k8s.io/client-go/util/workqueue"
 
 	kubevirtv1 "kubevirt.io/api/core/v1"
-	"kubevirt.io/client-go/kubecli"
 	"kubevirt.io/client-go/log"
 
 	"kubevirt.io/kubevirt/pkg/apimachinery/patch"
@@ -67,16 +67,14 @@ var nodeLabellerLabels = []string{
 // NodeLabeller struct holds information needed to run node-labeller
 type NodeLabeller struct {
 	recorder                record.EventRecorder
-	clientset               kubecli.KubevirtClient
+	nodeClient              k8scli.NodeInterface
 	host                    string
-	namespace               string
 	logger                  *log.FilteredLogger
 	clusterConfig           *virtconfig.ClusterConfig
 	hypervFeatures          supportedFeatures
 	hostCapabilities        supportedFeatures
 	queue                   workqueue.RateLimitingInterface
 	supportedFeatures       []string
-	cpuInfo                 cpuInfo
 	cpuModelVendor          string
 	volumePath              string
 	domCapabilitiesFileName string
@@ -85,16 +83,15 @@ type NodeLabeller struct {
 	SEV                     SEVConfiguration
 }
 
-func NewNodeLabeller(clusterConfig *virtconfig.ClusterConfig, clientset kubecli.KubevirtClient, host, namespace string, recorder record.EventRecorder) (*NodeLabeller, error) {
-	return newNodeLabeller(clusterConfig, clientset, host, namespace, nodeLabellerVolumePath, recorder)
+func NewNodeLabeller(clusterConfig *virtconfig.ClusterConfig, nodeClient k8scli.NodeInterface, host string, recorder record.EventRecorder) (*NodeLabeller, error) {
+	return newNodeLabeller(clusterConfig, nodeClient, host, nodeLabellerVolumePath, recorder)
 
 }
-func newNodeLabeller(clusterConfig *virtconfig.ClusterConfig, clientset kubecli.KubevirtClient, host, namespace string, volumePath string, recorder record.EventRecorder) (*NodeLabeller, error) {
+func newNodeLabeller(clusterConfig *virtconfig.ClusterConfig, nodeClient k8scli.NodeInterface, host, volumePath string, recorder record.EventRecorder) (*NodeLabeller, error) {
 	n := &NodeLabeller{
 		recorder:                recorder,
-		clientset:               clientset,
+		nodeClient:              nodeClient,
 		host:                    host,
-		namespace:               namespace,
 		logger:                  log.DefaultLogger(),
 		clusterConfig:           clusterConfig,
 		queue:                   workqueue.NewNamedRateLimitingQueue(workqueue.DefaultControllerRateLimiter(), "virt-handler-node-labeller"),
@@ -153,23 +150,17 @@ func (n *NodeLabeller) execute() bool {
 }
 
 func (n *NodeLabeller) loadAll() error {
-	err := n.loadCPUInfo()
-	if err != nil {
-		n.logger.Errorf("node-labeller could not load cpu info: " + err.Error())
-		return err
-	}
-
 	// host supported features is only available on AMD64 nodes.
 	// This is because hypervisor-cpu-baseline virsh command doesnt work for ARM64 architecture.
 	if virtconfig.IsAMD64(runtime.GOARCH) {
-		err = n.loadHostSupportedFeatures()
+		err := n.loadHostSupportedFeatures()
 		if err != nil {
 			n.logger.Errorf("node-labeller could not load supported features: " + err.Error())
 			return err
 		}
 	}
 
-	err = n.loadDomCapabilities()
+	err := n.loadDomCapabilities()
 	if err != nil {
 		n.logger.Errorf("node-labeller could not load host dom capabilities: " + err.Error())
 		return err
@@ -192,7 +183,7 @@ func (n *NodeLabeller) run() error {
 	cpuFeatures := n.getSupportedCpuFeatures()
 	hostCPUModel := n.GetHostCpuModel()
 
-	originalNode, err := n.clientset.CoreV1().Nodes().Get(context.Background(), n.host, metav1.GetOptions{})
+	originalNode, err := n.nodeClient.Get(context.Background(), n.host, metav1.GetOptions{})
 	if err != nil {
 		return err
 	}
@@ -251,7 +242,7 @@ func (n *NodeLabeller) patchNode(originalNode, node *v1.Node) error {
 		if err != nil {
 			return err
 		}
-		_, err = n.clientset.CoreV1().Nodes().Patch(context.Background(), node.Name, types.JSONPatchType, payloadBytes, metav1.PatchOptions{})
+		_, err = n.nodeClient.Patch(context.Background(), node.Name, types.JSONPatchType, payloadBytes, metav1.PatchOptions{})
 		if err != nil {
 			return err
 		}
@@ -273,10 +264,6 @@ func (n *NodeLabeller) prepareLabels(node *v1.Node, cpuModels []string, cpuFeatu
 	}
 
 	for _, value := range cpuModels {
-		if !n.shouldAddCPUModelLabel(value, &hostCpuModel, newLabels) {
-			continue
-		}
-
 		newLabels[kubevirtv1.CPUModelLabel+value] = "true"
 		newLabels[kubevirtv1.SupportedHostModelMigrationCPU+value] = "true"
 	}
@@ -386,35 +373,3 @@ func (n *NodeLabeller) alertIfHostModelIsObsolete(originalNode *v1.Node, hostMod
 	n.recorder.Eventf(originalNode, v1.EventTypeWarning, "HostModelIsObsolete", warningMsg)
 	return nil
 }
-
-func (n *NodeLabeller) shouldAddCPUModelLabel(
-	cpuModelName string,
-	hostCpuModel *hostCPUModel,
-	featureLabels map[string]string,
-) bool {
-	if cpuModelName == hostCpuModel.Name {
-		return true
-	}
-	// The logic below is necessary to handle the scenarios when libvirt's definition of a
-	// particular CPU model differs from hypervisor's definition.
-	// E.g. currently Opteron_G2 requires svm by libvirt:
-	//     /usr/share/libvirt/cpu_map/x86_Opteron_G2.xml
-	// But libvirt marks it as Usable:yes even without svm because it is usable by qemu:
-	//     /var/lib/kubevirt-node-labeller/virsh_domcapabilities.xml
-	// For more information refer to https://wiki.qemu.org/Features/CPUModels, "Getting
-	// information about CPU models" section.
-	// Another similar issue:
-	//     https://gitlab.com/libvirt/libvirt/-/issues/304
-	requiredFeatures, ok := n.cpuInfo.usableModels[cpuModelName]
-	if !ok {
-		n.logger.Warningf("The list of required features for CPU model %s is not defined", cpuModelName)
-		return false
-	}
-	missingFeatures := make([]string, 0)
-	for f := range requiredFeatures {
-		if _, isFeatureSupported := featureLabels[kubevirtv1.CPUFeatureLabel+f]; !isFeatureSupported {
-			missingFeatures = append(missingFeatures, f)
-		}
-	}
-	return len(missingFeatures) == 0
-}
