@@ -157,12 +157,18 @@ type FSFreeze struct {
 	Status string
 }
 
+type FSDisk struct {
+	Serial  string
+	BusType string
+}
+
 type Filesystem struct {
 	Name       string
 	Mountpoint string
 	Type       string
 	UsedBytes  int
 	TotalBytes int
+	Disk       []FSDisk
 }
 
 type User struct {
@@ -474,12 +480,17 @@ type MemoryBackingAccess struct {
 type NoSharePages struct {
 }
 
+type MemoryAddress struct {
+	Base string `xml:"base,attr"`
+}
+
 type MemoryTarget struct {
-	Size      Memory `xml:"size"`
-	Requested Memory `xml:"requested"`
-	Current   Memory `xml:"current"`
-	Node      string `xml:"node"`
-	Block     Memory `xml:"block"`
+	Size      Memory         `xml:"size"`
+	Requested Memory         `xml:"requested"`
+	Current   Memory         `xml:"current"`
+	Node      string         `xml:"node"`
+	Block     Memory         `xml:"block"`
+	Address   *MemoryAddress `xml:"address,omitempty"`
 }
 
 type MemoryDevice struct {
@@ -591,7 +602,7 @@ type HostDevice struct {
 	Source    HostDeviceSource `xml:"source"`
 	Type      string           `xml:"type,attr"`
 	BootOrder *BootOrder       `xml:"boot,omitempty"`
-	Managed   string           `xml:"managed,attr"`
+	Managed   string           `xml:"managed,attr,omitempty"`
 	Mode      string           `xml:"mode,attr,omitempty"`
 	Model     string           `xml:"model,attr,omitempty"`
 	Address   *Address         `xml:"address,omitempty"`
@@ -777,6 +788,7 @@ type ConsoleSource struct {
 // BEGIN Inteface -----------------------------
 
 type Interface struct {
+	XMLName             xml.Name               `xml:"interface"`
 	Address             *Address               `xml:"address,omitempty"`
 	Type                string                 `xml:"type,attr"`
 	TrustGuestRxFilters string                 `xml:"trustGuestRxFilters,attr,omitempty"`
@@ -934,6 +946,7 @@ func (alias *Alias) UnmarshalJSON(data []byte) error {
 
 type OS struct {
 	Type       OSType    `xml:"type"`
+	ACPI       *OSACPI   `xml:"acpi,omitempty"`
 	SMBios     *SMBios   `xml:"smbios,omitempty"`
 	BootOrder  []Boot    `xml:"boot"`
 	BootMenu   *BootMenu `xml:"bootmenu,omitempty"`
@@ -951,6 +964,15 @@ type OSType struct {
 	Machine string `xml:"machine,attr,omitempty"`
 }
 
+type OSACPI struct {
+	Table ACPITable `xml:"table,omitempty"`
+}
+
+type ACPITable struct {
+	Path string `xml:",chardata"`
+	Type string `xml:"type,attr,omitempty"`
+}
+
 type SMBios struct {
 	Mode string `xml:"mode,attr"`
 }
