@@ -159,24 +159,26 @@ func isARM64(arch string) bool {
 	return false
 }
 
+func assignDiskToSCSIController(disk *api.Disk, unit int) {
+	// Ensure we assign this disk to the correct scsi controller
+	if disk.Address == nil {
+		disk.Address = &api.Address{}
+	}
+	disk.Address.Type = "drive"
+	// This should be the index of the virtio-scsi controller, which is hard coded to 0
+	disk.Address.Controller = "0"
+	disk.Address.Bus = "0"
+	disk.Address.Unit = strconv.Itoa(unit)
+}
+
 func Convert_v1_Disk_To_api_Disk(c *ConverterContext, diskDevice *v1.Disk, disk *api.Disk, prefixMap map[string]deviceNamer, numQueues *uint, volumeStatusMap map[string]v1.VolumeStatus) error {
 	if diskDevice.Disk != nil {
 		var unit int
 		disk.Device = "disk"
 		disk.Target.Bus = diskDevice.Disk.Bus
-		if diskDevice.Disk.Bus == "scsi" {
-			// Ensure we assign this disk to the correct scsi controller
-			if disk.Address == nil {
-				disk.Address = &api.Address{}
-			}
-			disk.Address.Type = "drive"
-			// This should be the index of the virtio-scsi controller, which is hard coded to 0
-			disk.Address.Controller = "0"
-			disk.Address.Bus = "0"
-		}
 		disk.Target.Device, unit = makeDeviceName(diskDevice.Name, diskDevice.Disk.Bus, prefixMap)
 		if diskDevice.Disk.Bus == "scsi" {
-			disk.Address.Unit = strconv.Itoa(unit)
+			assignDiskToSCSIController(disk, unit)
 		}
 		if diskDevice.Disk.PciAddress != "" {
 			if diskDevice.Disk.Bus != v1.DiskBusVirtio {
@@ -205,9 +207,13 @@ func Convert_v1_Disk_To_api_Disk(c *ConverterContext, diskDevice *v1.Disk, disk
 			}
 		}
 	} else if diskDevice.LUN != nil {
+		var unit int
 		disk.Device = "lun"
 		disk.Target.Bus = diskDevice.LUN.Bus
-		disk.Target.Device, _ = makeDeviceName(diskDevice.Name, diskDevice.LUN.Bus, prefixMap)
+		disk.Target.Device, unit = makeDeviceName(diskDevice.Name, diskDevice.LUN.Bus, prefixMap)
+		if diskDevice.LUN.Bus == "scsi" {
+			assignDiskToSCSIController(disk, unit)
+		}
 		disk.ReadOnly = toApiReadOnly(diskDevice.LUN.ReadOnly)
 		if diskDevice.LUN.Reservation {
 			setReservation(disk)
@@ -1297,6 +1303,87 @@ func setupDomainMemory(vmi *v1.VirtualMachineInstance, domain *api.Domain) error
 	return nil
 }
 
+func Convert_v1_Firmware_To_related_apis(vmi *v1.VirtualMachineInstance, domain *api.Domain, c *ConverterContext) error {
+	firmware := vmi.Spec.Domain.Firmware
+	if firmware == nil {
+		return nil
+	}
+
+	domain.Spec.SysInfo.System = []api.Entry{
+		{
+			Name:  "uuid",
+			Value: string(firmware.UUID),
+		},
+	}
+
+	if util.IsEFIVMI(vmi) {
+		domain.Spec.OS.BootLoader = &api.Loader{
+			Path:     c.EFIConfiguration.EFICode,
+			ReadOnly: "yes",
+			Secure:   boolToYesNo(&c.EFIConfiguration.SecureLoader, false),
+			Type:     "pflash",
+		}
+
+		domain.Spec.OS.NVRam = &api.NVRam{
+			Template: c.EFIConfiguration.EFIVars,
+			NVRam:    filepath.Join(services.PathForNVram(vmi), vmi.Name+"_VARS.fd"),
+		}
+	}
+
+	if firmware.Bootloader != nil && firmware.Bootloader.BIOS != nil {
+		if firmware.Bootloader.BIOS.UseSerial != nil && *firmware.Bootloader.BIOS.UseSerial {
+			domain.Spec.OS.BIOS = &api.BIOS{
+				UseSerial: "yes",
+			}
+		}
+	}
+
+	if len(firmware.Serial) > 0 {
+		domain.Spec.SysInfo.System = append(domain.Spec.SysInfo.System, api.Entry{
+			Name:  "serial",
+			Value: string(firmware.Serial),
+		})
+	}
+
+	if util.HasKernelBootContainerImage(vmi) {
+		kb := firmware.KernelBoot
+
+		log.Log.Object(vmi).Infof("kernel boot defined for VMI. Converting to domain XML")
+		if kb.Container.KernelPath != "" {
+			kernelPath := containerdisk.GetKernelBootArtifactPathFromLauncherView(kb.Container.KernelPath)
+			log.Log.Object(vmi).Infof("setting kernel path for kernel boot: " + kernelPath)
+			domain.Spec.OS.Kernel = kernelPath
+		}
+
+		if kb.Container.InitrdPath != "" {
+			initrdPath := containerdisk.GetKernelBootArtifactPathFromLauncherView(kb.Container.InitrdPath)
+			log.Log.Object(vmi).Infof("setting initrd path for kernel boot: " + initrdPath)
+			domain.Spec.OS.Initrd = initrdPath
+		}
+
+	}
+
+	// Define custom command-line arguments even if kernel-boot container is not defined
+	if firmware.KernelBoot != nil {
+		log.Log.Object(vmi).Infof("setting custom kernel arguments: " + firmware.KernelBoot.KernelArgs)
+		domain.Spec.OS.KernelArgs = firmware.KernelBoot.KernelArgs
+	}
+
+	if firmware.ACPI != nil {
+		if slicNameRef := firmware.ACPI.SlicNameRef; slicNameRef != "" {
+			path := fmt.Sprintf("/var/run/kubevirt-private/secret/%s/slic.bin", slicNameRef)
+			domain.Spec.OS.ACPI = &api.OSACPI{
+				Table: api.ACPITable{
+					Type: "slic",
+					Path: path,
+				},
+			}
+		}
+	}
+
+	return nil
+}
+
 func Convert_v1_VirtualMachineInstance_To_api_Domain(vmi *v1.VirtualMachineInstance, domain *api.Domain, c *ConverterContext) (err error) {
 	var controllerDriver *api.ControllerDriver
 
@@ -1367,65 +1454,12 @@ func Convert_v1_VirtualMachineInstance_To_api_Domain(vmi *v1.VirtualMachineInsta
 	}
 
 	domain.Spec.SysInfo = &api.SysInfo{}
-	if vmi.Spec.Domain.Firmware != nil {
-		domain.Spec.SysInfo.System = []api.Entry{
-			{
-				Name:  "uuid",
-				Value: string(vmi.Spec.Domain.Firmware.UUID),
-			},
-		}
-
-		if util.IsEFIVMI(vmi) {
-			domain.Spec.OS.BootLoader = &api.Loader{
-				Path:     c.EFIConfiguration.EFICode,
-				ReadOnly: "yes",
-				Secure:   boolToYesNo(&c.EFIConfiguration.SecureLoader, false),
-				Type:     "pflash",
-			}
-
-			domain.Spec.OS.NVRam = &api.NVRam{
-				Template: c.EFIConfiguration.EFIVars,
-				NVRam:    filepath.Join(services.PathForNVram(vmi), vmi.Name+"_VARS.fd"),
-			}
-		}
-
-		if vmi.Spec.Domain.Firmware.Bootloader != nil && vmi.Spec.Domain.Firmware.Bootloader.BIOS != nil {
-			if vmi.Spec.Domain.Firmware.Bootloader.BIOS.UseSerial != nil && *vmi.Spec.Domain.Firmware.Bootloader.BIOS.UseSerial {
-				domain.Spec.OS.BIOS = &api.BIOS{
-					UseSerial: "yes",
-				}
-			}
-		}
-
-		if len(vmi.Spec.Domain.Firmware.Serial) > 0 {
-			domain.Spec.SysInfo.System = append(domain.Spec.SysInfo.System, api.Entry{Name: "serial", Value: string(vmi.Spec.Domain.Firmware.Serial)})
-		}
-
-		if util.HasKernelBootContainerImage(vmi) {
-			kb := vmi.Spec.Domain.Firmware.KernelBoot
-
-			log.Log.Object(vmi).Infof("kernel boot defined for VMI. Converting to domain XML")
-			if kb.Container.KernelPath != "" {
-				kernelPath := containerdisk.GetKernelBootArtifactPathFromLauncherView(kb.Container.KernelPath)
-				log.Log.Object(vmi).Infof("setting kernel path for kernel boot: " + kernelPath)
-				domain.Spec.OS.Kernel = kernelPath
-			}
-
-			if kb.Container.InitrdPath != "" {
-				initrdPath := containerdisk.GetKernelBootArtifactPathFromLauncherView(kb.Container.InitrdPath)
-				log.Log.Object(vmi).Infof("setting initrd path for kernel boot: " + initrdPath)
-				domain.Spec.OS.Initrd = initrdPath
-			}
-
-		}
-
-		// Define custom command-line arguments even if kernel-boot container is not defined
-		if f := vmi.Spec.Domain.Firmware; f != nil && f.KernelBoot != nil {
-			log.Log.Object(vmi).Infof("setting custom kernel arguments: " + f.KernelBoot.KernelArgs)
-			domain.Spec.OS.KernelArgs = f.KernelBoot.KernelArgs
-		}
 
+	err = Convert_v1_Firmware_To_related_apis(vmi, domain, c)
+	if err != nil {
+		return err
 	}
+
 	// Set SEV launch security parameters: https://libvirt.org/formatdomain.html#launch-security
 	if c.UseLaunchSecurity {
 		sevPolicyBits := launchsecurity.SEVPolicyToBits(vmi.Spec.Domain.LaunchSecurity.SEV.Policy)
@@ -1652,7 +1686,10 @@ func Convert_v1_VirtualMachineInstance_To_api_Domain(vmi *v1.VirtualMachineInsta
 		}
 
 		if useIOThreads {
-			if _, ok := c.HotplugVolumes[disk.Name]; !ok {
+			bus := getBusFromDisk(disk)
+			switch bus {
+			// Only disks with virtio bus support IOThreads
+			case v1.DiskBusVirtio:
 				ioThreadId := defaultIOThread
 				dedicatedThread := false
 				if disk.DedicatedIOThread != nil {
@@ -1669,8 +1706,14 @@ func Convert_v1_VirtualMachineInstance_To_api_Domain(vmi *v1.VirtualMachineInsta
 					currentAutoThread = (currentAutoThread % uint(autoThreads)) + 1
 				}
 				newDisk.Driver.IOThread = &ioThreadId
-			} else {
+
+			// We can find a workaround by adding IOThreads to the SCSI controller
+			case v1.DiskBusSCSI:
 				newDisk.Driver.IO = v1.IOThreads
+
+			default:
+				// TODO: if possible, find a workaround for SATA and USB buses.
+				log.Log.Infof("IOthreads not available for disk %s: Bus %s not supported", disk.Name, bus)
 			}
 		}
 
@@ -1727,20 +1770,16 @@ func Convert_v1_VirtualMachineInstance_To_api_Domain(vmi *v1.VirtualMachineInsta
 		return err
 	}
 
-	if isUSBNeeded(c, vmi) {
-		domain.Spec.Devices.Controllers = append(domain.Spec.Devices.Controllers, api.Controller{
-			Type:  "usb",
-			Index: "0",
-			Model: "qemu-xhci",
-		})
-	} else {
-		// disable usb controller
-		domain.Spec.Devices.Controllers = append(domain.Spec.Devices.Controllers, api.Controller{
-			Type:  "usb",
-			Index: "0",
-			Model: "none",
-		})
+	// Creating USB controller, disabled by default
+	usbController := api.Controller{
+		Type:  "usb",
+		Index: "0",
+		Model: "none",
 	}
+	if isUSBNeeded(c, vmi) {
+		usbController.Model = "qemu-xhci"
+	}
+	domain.Spec.Devices.Controllers = append(domain.Spec.Devices.Controllers, usbController)
 
 	if needsSCSIController(vmi) {
 		scsiController := api.Controller{
@@ -1793,8 +1832,10 @@ func Convert_v1_VirtualMachineInstance_To_api_Domain(vmi *v1.VirtualMachineInsta
 		}
 
 		// Set VM CPU features
+		existingFeatures := make(map[string]struct{})
 		if vmi.Spec.Domain.CPU.Features != nil {
 			for _, feature := range vmi.Spec.Domain.CPU.Features {
+				existingFeatures[feature.Name] = struct{}{}
 				domain.Spec.CPU.Features = append(domain.Spec.CPU.Features, api.CPUFeature{
 					Name:   feature.Name,
 					Policy: feature.Policy,
@@ -1802,6 +1843,25 @@ func Convert_v1_VirtualMachineInstance_To_api_Domain(vmi *v1.VirtualMachineInsta
 			}
 		}
 
+		/*
+						Libvirt validation fails when a CPU model is usable
+						by QEMU but lacks features listed in
+						`/usr/share/libvirt/cpu_map/[CPU Model].xml` on a node
+						To avoid the validation error mentioned above we can disable
+						deprecated features in the `/usr/share/libvirt/cpu_map/[CPU Model].xml` files.
+						Examples of validation error:
+			    		https://bugzilla.redhat.com/show_bug.cgi?id=2122283 - resolve by obsolete Opteron_G2
+						https://gitlab.com/libvirt/libvirt/-/issues/304 - resolve by disabling mpx which is deprecated
+						Issue in Libvirt: https://gitlab.com/libvirt/libvirt/-/issues/608
+						once the issue is resolved we can remove mpx disablement
+		*/
+		if _, exists := existingFeatures["mpx"]; !exists && vmi.Spec.Domain.CPU.Model != v1.CPUModeHostModel && vmi.Spec.Domain.CPU.Model != v1.CPUModeHostPassthrough {
+			domain.Spec.CPU.Features = append(domain.Spec.CPU.Features, api.CPUFeature{
+				Name:   "mpx",
+				Policy: "disable",
+			})
+		}
+
 		// Adjust guest vcpu config. Currently will handle vCPUs to pCPUs pinning
 		if vmi.IsCPUDedicated() {
 			err = vcpu.AdjustDomainForTopologyAndCPUSet(domain, vmi, c.Topology, c.CPUSet, useIOThreads)
@@ -2057,19 +2117,26 @@ func GetImageInfo(imagePath string) (*containerdisk.DiskInfo, error) {
 
 func needsSCSIController(vmi *v1.VirtualMachineInstance) bool {
 	for _, disk := range vmi.Spec.Domain.Devices.Disks {
-		if disk.LUN != nil && disk.LUN.Bus == "scsi" {
-			return true
-		}
-		if disk.Disk != nil && disk.Disk.Bus == "scsi" {
-			return true
-		}
-		if disk.CDRom != nil && disk.CDRom.Bus == "scsi" {
+		if getBusFromDisk(disk) == v1.DiskBusSCSI {
 			return true
 		}
 	}
 	return !vmi.Spec.Domain.Devices.DisableHotplug
 }
 
+func getBusFromDisk(disk v1.Disk) v1.DiskBus {
+	if disk.LUN != nil {
+		return disk.LUN.Bus
+	}
+	if disk.Disk != nil {
+		return disk.Disk.Bus
+	}
+	if disk.CDRom != nil {
+		return disk.CDRom.Bus
+	}
+	return ""
+}
+
 func getPrefixFromBus(bus v1.DiskBus) string {
 	switch bus {
 	case v1.DiskBusVirtio:
