@@ -32,6 +32,7 @@ import (
 	"strings"
 	"time"
 
+	"kubevirt.io/kubevirt/pkg/network/vmispec"
 	"kubevirt.io/kubevirt/pkg/testutils"
 	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
 
@@ -2173,6 +2174,12 @@ var _ = Describe("Manager", func() {
 					Multus: &v1.MultusNetwork{NetworkName: "test1"},
 				}},
 		)
+		vmi.Status = v1.VirtualMachineInstanceStatus{
+			Interfaces: []v1.VirtualMachineInstanceNetworkInterface{{
+				Name:       "test1",
+				InfoSource: vmispec.InfoSourceMultusStatus,
+			}},
+		}
 
 		domainSpec := expectedDomainFor(vmi)
 		xml, err := xml.MarshalIndent(domainSpec, "", "\t")
@@ -2201,6 +2208,12 @@ var _ = Describe("Manager", func() {
 				Type:       "fs",
 				UsedBytes:  0,
 				TotalBytes: 0,
+				Disk: []api.FSDisk{
+					{
+						BusType: "scsi",
+						Serial:  "testserial-1234",
+					},
+				},
 			},
 		})
 
@@ -2221,6 +2234,12 @@ var _ = Describe("Manager", func() {
 			FileSystemType: "fs",
 			UsedBytes:      0,
 			TotalBytes:     0,
+			Disk: []v1.VirtualMachineInstanceFileSystemDisk{
+				{
+					BusType: "scsi",
+					Serial:  "testserial-1234",
+				},
+			},
 		}))
 	})
 
@@ -2252,6 +2271,12 @@ var _ = Describe("Manager", func() {
 				Type:       "fs",
 				UsedBytes:  0,
 				TotalBytes: 0,
+				Disk: []api.FSDisk{
+					{
+						BusType: "scsi",
+						Serial:  "testserial-1234",
+					},
+				},
 			},
 		})
 
@@ -2273,6 +2298,12 @@ var _ = Describe("Manager", func() {
 				Type:       "fs",
 				UsedBytes:  0,
 				TotalBytes: 0,
+				Disk: []api.FSDisk{
+					{
+						BusType: "scsi",
+						Serial:  "testserial-1234",
+					},
+				},
 			},
 		})
 
@@ -2313,6 +2344,12 @@ var _ = Describe("Manager", func() {
 				Type:       "fs",
 				UsedBytes:  0,
 				TotalBytes: 0,
+				Disk: []api.FSDisk{
+					{
+						BusType: "scsi",
+						Serial:  "testserial-1234",
+					},
+				},
 			},
 		})
 
@@ -2502,7 +2539,6 @@ var _ = Describe("getDetachedDisks", func() {
 			[]api.Disk{}),
 	)
 })
-
 var _ = Describe("migratableDomXML", func() {
 	var ctrl *gomock.Controller
 	var mockDomain *cli.MockVirDomain
@@ -2510,15 +2546,20 @@ var _ = Describe("migratableDomXML", func() {
 		ctrl = gomock.NewController(GinkgoT())
 		mockDomain = cli.NewMockVirDomain(ctrl)
 	})
-	It("should remove metadata", func() {
+	It("should parse the XML with the metadata", func() {
 		domXML := `<domain type="kvm" id="1">
   <name>kubevirt</name>
-  <kubevirt><migration>this should stay</migration></kubevirt>
+  <metadata>
+    <kubevirt xmlns="http://kubevirt.io">
+    </kubevirt>
+   </metadata>
 </domain>`
-		// migratableDomXML() removes the migration block but not its ident, which is its own token, hence the blank line below
 		expectedXML := `<domain type="kvm" id="1">
   <name>kubevirt</name>
-  <kubevirt><migration>this should stay</migration></kubevirt>
+  <metadata>
+    <kubevirt xmlns="http://kubevirt.io">
+    </kubevirt>
+   </metadata>
 </domain>`
 		vmi := newVMI("testns", "kubevirt")
 		mockDomain.EXPECT().GetXMLDesc(libvirt.DOMAIN_XML_MIGRATABLE).MaxTimes(1).Return(domXML, nil)
@@ -2545,6 +2586,9 @@ var _ = Describe("migratableDomXML", func() {
     <vcpupin vcpu="0" cpuset="6"></vcpupin>
     <vcpupin vcpu="1" cpuset="7"></vcpupin>
   </cputune>
+  <cpu>
+    <topology sockets="1" cores="2" threads="1"></topology>
+  </cpu>
 </domain>`
 
 		By("creating a VMI with dedicated CPU cores")
