@@ -7,7 +7,7 @@ import (
 
 	"github.com/golang/glog"
 
-	"kubevirt.io/client-go/kubecli"
+	kvcorev1 "kubevirt.io/client-go/generated/kubevirt/clientset/versioned/typed/core/v1"
 )
 
 type portForwarder struct {
@@ -16,7 +16,7 @@ type portForwarder struct {
 }
 
 type portforwardableResource interface {
-	PortForward(name string, port int, protocol string) (kubecli.StreamInterface, error)
+	PortForward(name string, port int, protocol string) (kvcorev1.StreamInterface, error)
 }
 
 func (p *portForwarder) startForwarding(address *net.IPAddr, port forwardedPort) error {
